Method: Aws::CodeDeploy::Types::UpdateDeploymentGroupOutput#hooks_not_cleaned_up

Defined in:
lib/aws-sdk-codedeploy/types.rb

#hooks_not_cleaned_upArray<Types::AutoScalingGroup>

If the output contains no data, and the corresponding deployment group contained at least one Auto Scaling group, CodeDeploy successfully removed all corresponding Auto Scaling lifecycle event hooks from the Amazon Web Services account. If the output contains data, CodeDeploy could not remove some Auto Scaling lifecycle event hooks from the Amazon Web Services account.

Returns:



5171
5172
5173
5174
5175
# File 'lib/aws-sdk-codedeploy/types.rb', line 5171

class UpdateDeploymentGroupOutput < Struct.new(
  :hooks_not_cleaned_up)
  SENSITIVE = []
  include Aws::Structure
end