Class: Aws::CodeDeploy::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CodeDeploy::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-codedeploy/client.rb,
sig/client.rbs
Overview
An API client for CodeDeploy. To construct a client, you need to configure a :region and :credentials.
client = Aws::CodeDeploy::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchGetApplicationRevisionsResponseSuccess, _BatchGetApplicationsResponseSuccess, _BatchGetDeploymentGroupsResponseSuccess, _BatchGetDeploymentInstancesResponseSuccess, _BatchGetDeploymentTargetsResponseSuccess, _BatchGetDeploymentsResponseSuccess, _BatchGetOnPremisesInstancesResponseSuccess, _CreateApplicationResponseSuccess, _CreateDeploymentConfigResponseSuccess, _CreateDeploymentGroupResponseSuccess, _CreateDeploymentResponseSuccess, _DeleteDeploymentGroupResponseSuccess, _DeleteGitHubAccountTokenResponseSuccess, _DeleteResourcesByExternalIdResponseSuccess, _GetApplicationResponseSuccess, _GetApplicationRevisionResponseSuccess, _GetDeploymentConfigResponseSuccess, _GetDeploymentGroupResponseSuccess, _GetDeploymentInstanceResponseSuccess, _GetDeploymentResponseSuccess, _GetDeploymentTargetResponseSuccess, _GetOnPremisesInstanceResponseSuccess, _ListApplicationRevisionsResponseSuccess, _ListApplicationsResponseSuccess, _ListDeploymentConfigsResponseSuccess, _ListDeploymentGroupsResponseSuccess, _ListDeploymentInstancesResponseSuccess, _ListDeploymentTargetsResponseSuccess, _ListDeploymentsResponseSuccess, _ListGitHubAccountTokenNamesResponseSuccess, _ListOnPremisesInstancesResponseSuccess, _ListTagsForResourceResponseSuccess, _PutLifecycleEventHookExecutionStatusResponseSuccess, _StopDeploymentResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateDeploymentGroupResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_tags_to_on_premises_instances(params = {}) ⇒ Struct
Adds tags to on-premises instances.
-
#batch_get_application_revisions(params = {}) ⇒ Types::BatchGetApplicationRevisionsOutput
Gets information about one or more application revisions.
-
#batch_get_applications(params = {}) ⇒ Types::BatchGetApplicationsOutput
Gets information about one or more applications.
-
#batch_get_deployment_groups(params = {}) ⇒ Types::BatchGetDeploymentGroupsOutput
Gets information about one or more deployment groups.
-
#batch_get_deployment_instances(params = {}) ⇒ Types::BatchGetDeploymentInstancesOutput
This method works, but is deprecated. -
#batch_get_deployment_targets(params = {}) ⇒ Types::BatchGetDeploymentTargetsOutput
Returns an array of one or more targets associated with a deployment.
-
#batch_get_deployments(params = {}) ⇒ Types::BatchGetDeploymentsOutput
Gets information about one or more deployments.
-
#batch_get_on_premises_instances(params = {}) ⇒ Types::BatchGetOnPremisesInstancesOutput
Gets information about one or more on-premises instances.
-
#continue_deployment(params = {}) ⇒ Struct
For a blue/green deployment, starts the process of rerouting traffic from instances in the original environment to instances in the replacement environment without waiting for a specified wait time to elapse.
-
#create_application(params = {}) ⇒ Types::CreateApplicationOutput
Creates an application.
-
#create_deployment(params = {}) ⇒ Types::CreateDeploymentOutput
Deploys an application revision through the specified deployment group.
-
#create_deployment_config(params = {}) ⇒ Types::CreateDeploymentConfigOutput
Creates a deployment configuration.
-
#create_deployment_group(params = {}) ⇒ Types::CreateDeploymentGroupOutput
Creates a deployment group to which application revisions are deployed.
-
#delete_application(params = {}) ⇒ Struct
Deletes an application.
-
#delete_deployment_config(params = {}) ⇒ Struct
Deletes a deployment configuration.
-
#delete_deployment_group(params = {}) ⇒ Types::DeleteDeploymentGroupOutput
Deletes a deployment group.
-
#delete_git_hub_account_token(params = {}) ⇒ Types::DeleteGitHubAccountTokenOutput
Deletes a GitHub account connection.
-
#delete_resources_by_external_id(params = {}) ⇒ Struct
Deletes resources linked to an external ID.
-
#deregister_on_premises_instance(params = {}) ⇒ Struct
Deregisters an on-premises instance.
-
#get_application(params = {}) ⇒ Types::GetApplicationOutput
Gets information about an application.
-
#get_application_revision(params = {}) ⇒ Types::GetApplicationRevisionOutput
Gets information about an application revision.
-
#get_deployment(params = {}) ⇒ Types::GetDeploymentOutput
Gets information about a deployment.
-
#get_deployment_config(params = {}) ⇒ Types::GetDeploymentConfigOutput
Gets information about a deployment configuration.
-
#get_deployment_group(params = {}) ⇒ Types::GetDeploymentGroupOutput
Gets information about a deployment group.
-
#get_deployment_instance(params = {}) ⇒ Types::GetDeploymentInstanceOutput
Gets information about an instance as part of a deployment.
-
#get_deployment_target(params = {}) ⇒ Types::GetDeploymentTargetOutput
Returns information about a deployment target.
-
#get_on_premises_instance(params = {}) ⇒ Types::GetOnPremisesInstanceOutput
Gets information about an on-premises instance.
-
#list_application_revisions(params = {}) ⇒ Types::ListApplicationRevisionsOutput
Lists information about revisions for an application.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsOutput
Lists the applications registered with the user or Amazon Web Services account.
-
#list_deployment_configs(params = {}) ⇒ Types::ListDeploymentConfigsOutput
Lists the deployment configurations with the user or Amazon Web Services account.
-
#list_deployment_groups(params = {}) ⇒ Types::ListDeploymentGroupsOutput
Lists the deployment groups for an application registered with the Amazon Web Services user or Amazon Web Services account.
-
#list_deployment_instances(params = {}) ⇒ Types::ListDeploymentInstancesOutput
The newer BatchGetDeploymentTargetsshould be used instead because it works with all compute types. -
#list_deployment_targets(params = {}) ⇒ Types::ListDeploymentTargetsOutput
Returns an array of target IDs that are associated a deployment.
-
#list_deployments(params = {}) ⇒ Types::ListDeploymentsOutput
Lists the deployments in a deployment group for an application registered with the user or Amazon Web Services account.
-
#list_git_hub_account_token_names(params = {}) ⇒ Types::ListGitHubAccountTokenNamesOutput
Lists the names of stored connections to GitHub accounts.
-
#list_on_premises_instances(params = {}) ⇒ Types::ListOnPremisesInstancesOutput
Gets a list of names for one or more on-premises instances.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns a list of tags for the resource identified by a specified Amazon Resource Name (ARN).
-
#put_lifecycle_event_hook_execution_status(params = {}) ⇒ Types::PutLifecycleEventHookExecutionStatusOutput
Sets the result of a Lambda validation function.
-
#register_application_revision(params = {}) ⇒ Struct
Registers with CodeDeploy a revision for the specified application.
-
#register_on_premises_instance(params = {}) ⇒ Struct
Registers an on-premises instance.
-
#remove_tags_from_on_premises_instances(params = {}) ⇒ Struct
Removes one or more tags from one or more on-premises instances.
-
#skip_wait_time_for_instance_termination(params = {}) ⇒ Struct
In a blue/green deployment, overrides any specified wait time and starts terminating instances immediately after the traffic routing is complete.
-
#stop_deployment(params = {}) ⇒ Types::StopDeploymentOutput
Attempts to stop an ongoing deployment.
-
#tag_resource(params = {}) ⇒ Struct
Associates the list of tags in the input
Tagsparameter with the resource identified by theResourceArninput parameter. -
#untag_resource(params = {}) ⇒ Struct
Disassociates a resource from a list of tags.
-
#update_application(params = {}) ⇒ Struct
Changes the name of an application.
-
#update_deployment_group(params = {}) ⇒ Types::UpdateDeploymentGroupOutput
Changes information about a deployment group.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-codedeploy/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3799 3800 3801 |
# File 'lib/aws-sdk-codedeploy/client.rb', line 3799 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3802 3803 3804 |
# File 'lib/aws-sdk-codedeploy/client.rb', line 3802 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#add_tags_to_on_premises_instances(params = {}) ⇒ Struct
Adds tags to on-premises instances.
83 |
# File 'sig/client.rbs', line 83
def add_tags_to_on_premises_instances: (
|
#batch_get_application_revisions(params = {}) ⇒ Types::BatchGetApplicationRevisionsOutput
Gets information about one or more application revisions. The maximum number of application revisions that can be returned is 25.
101 |
# File 'sig/client.rbs', line 101
def batch_get_application_revisions: (
|
#batch_get_applications(params = {}) ⇒ Types::BatchGetApplicationsOutput
Gets information about one or more applications. The maximum number of applications that can be returned is 100.
114 |
# File 'sig/client.rbs', line 114
def batch_get_applications: (
|
#batch_get_deployment_groups(params = {}) ⇒ Types::BatchGetDeploymentGroupsOutput
Gets information about one or more deployment groups.
125 |
# File 'sig/client.rbs', line 125
def batch_get_deployment_groups: (
|
#batch_get_deployment_instances(params = {}) ⇒ Types::BatchGetDeploymentInstancesOutput
BatchGetDeploymentTargets
instead.
Returns an array of one or more instances associated with a
deployment. This method works with EC2/On-premises and Lambda compute
platforms. The newer BatchGetDeploymentTargets works with all
compute platforms. The maximum number of instances that can be
returned is 25.
137 |
# File 'sig/client.rbs', line 137
def batch_get_deployment_instances: (
|
#batch_get_deployment_targets(params = {}) ⇒ Types::BatchGetDeploymentTargetsOutput
Returns an array of one or more targets associated with a deployment.
This method works with all compute types and should be used instead of
the deprecated BatchGetDeploymentInstances. The maximum number of
targets that can be returned is 25.
The type of targets returned depends on the deployment's compute platform or deployment method:
-
EC2/On-premises: Information about Amazon EC2 instance targets.
-
Lambda: Information about Lambda functions targets.
-
Amazon ECS: Information about Amazon ECS service targets.
-
CloudFormation: Information about targets of blue/green deployments initiated by a CloudFormation stack update.
148 |
# File 'sig/client.rbs', line 148
def batch_get_deployment_targets: (
|
#batch_get_deployments(params = {}) ⇒ Types::BatchGetDeploymentsOutput
Gets information about one or more deployments. The maximum number of deployments that can be returned is 25.
159 |
# File 'sig/client.rbs', line 159
def batch_get_deployments: (
|
#batch_get_on_premises_instances(params = {}) ⇒ Types::BatchGetOnPremisesInstancesOutput
Gets information about one or more on-premises instances. The maximum number of on-premises instances that can be returned is 25.
169 |
# File 'sig/client.rbs', line 169
def batch_get_on_premises_instances: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3659 3660 3661 3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 |
# File 'lib/aws-sdk-codedeploy/client.rb', line 3659 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CodeDeploy') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-codedeploy' context[:gem_version] = '1.103.0' Seahorse::Client::Request.new(handlers, context) end |
#continue_deployment(params = {}) ⇒ Struct
For a blue/green deployment, starts the process of rerouting traffic from instances in the original environment to instances in the replacement environment without waiting for a specified wait time to elapse. (Traffic rerouting, which is achieved by registering instances in the replacement environment with the load balancer, can start as soon as all instances have a status of Ready.)
175 |
# File 'sig/client.rbs', line 175
def continue_deployment: (
|
#create_application(params = {}) ⇒ Types::CreateApplicationOutput
Creates an application.
186 |
# File 'sig/client.rbs', line 186
def create_application: (
|
#create_deployment(params = {}) ⇒ Types::CreateDeploymentOutput
Deploys an application revision through the specified deployment group.
203 |
# File 'sig/client.rbs', line 203
def create_deployment: (
|
#create_deployment_config(params = {}) ⇒ Types::CreateDeploymentConfigOutput
Creates a deployment configuration.
255 |
# File 'sig/client.rbs', line 255
def create_deployment_config: (
|
#create_deployment_group(params = {}) ⇒ Types::CreateDeploymentGroupOutput
Creates a deployment group to which application revisions are deployed.
289 |
# File 'sig/client.rbs', line 289
def create_deployment_group: (
|
#delete_application(params = {}) ⇒ Struct
Deletes an application.
375 |
# File 'sig/client.rbs', line 375
def delete_application: (
|
#delete_deployment_config(params = {}) ⇒ Struct
Deletes a deployment configuration.
381 |
# File 'sig/client.rbs', line 381
def delete_deployment_config: (
|
#delete_deployment_group(params = {}) ⇒ Types::DeleteDeploymentGroupOutput
Deletes a deployment group.
391 |
# File 'sig/client.rbs', line 391
def delete_deployment_group: (
|
#delete_git_hub_account_token(params = {}) ⇒ Types::DeleteGitHubAccountTokenOutput
Deletes a GitHub account connection.
402 |
# File 'sig/client.rbs', line 402
def delete_git_hub_account_token: (
|
#delete_resources_by_external_id(params = {}) ⇒ Struct
Deletes resources linked to an external ID. This action only applies if you have configured blue/green deployments through CloudFormation.
411 |
# File 'sig/client.rbs', line 411
def delete_resources_by_external_id: (
|
#deregister_on_premises_instance(params = {}) ⇒ Struct
Deregisters an on-premises instance.
417 |
# File 'sig/client.rbs', line 417
def deregister_on_premises_instance: (
|
#get_application(params = {}) ⇒ Types::GetApplicationOutput
Gets information about an application.
427 |
# File 'sig/client.rbs', line 427
def get_application: (
|
#get_application_revision(params = {}) ⇒ Types::GetApplicationRevisionOutput
Gets information about an application revision.
439 |
# File 'sig/client.rbs', line 439
def get_application_revision: (
|
#get_deployment(params = {}) ⇒ Types::GetDeploymentOutput
Gets information about a deployment.
content property of the appSpecContent object in the returned
revision is always null. Use GetApplicationRevision and the sha256
property of the returned appSpecContent object to get the content of
the deployment’s AppSpec file.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* deployment_successful
450 |
# File 'sig/client.rbs', line 450
def get_deployment: (
|
#get_deployment_config(params = {}) ⇒ Types::GetDeploymentConfigOutput
Gets information about a deployment configuration.
460 |
# File 'sig/client.rbs', line 460
def get_deployment_config: (
|
#get_deployment_group(params = {}) ⇒ Types::GetDeploymentGroupOutput
Gets information about a deployment group.
470 |
# File 'sig/client.rbs', line 470
def get_deployment_group: (
|
#get_deployment_instance(params = {}) ⇒ Types::GetDeploymentInstanceOutput
Gets information about an instance as part of a deployment.
481 |
# File 'sig/client.rbs', line 481
def get_deployment_instance: (
|
#get_deployment_target(params = {}) ⇒ Types::GetDeploymentTargetOutput
Returns information about a deployment target.
492 |
# File 'sig/client.rbs', line 492
def get_deployment_target: (
|
#get_on_premises_instance(params = {}) ⇒ Types::GetOnPremisesInstanceOutput
Gets information about an on-premises instance.
503 |
# File 'sig/client.rbs', line 503
def get_on_premises_instance: (
|
#list_application_revisions(params = {}) ⇒ Types::ListApplicationRevisionsOutput
Lists information about revisions for an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
514 |
# File 'sig/client.rbs', line 514
def list_application_revisions: (
|
#list_applications(params = {}) ⇒ Types::ListApplicationsOutput
Lists the applications registered with the user or Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
531 |
# File 'sig/client.rbs', line 531
def list_applications: (
|
#list_deployment_configs(params = {}) ⇒ Types::ListDeploymentConfigsOutput
Lists the deployment configurations with the user or Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
542 |
# File 'sig/client.rbs', line 542
def list_deployment_configs: (
|
#list_deployment_groups(params = {}) ⇒ Types::ListDeploymentGroupsOutput
Lists the deployment groups for an application registered with the Amazon Web Services user or Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
554 |
# File 'sig/client.rbs', line 554
def list_deployment_groups: (
|
#list_deployment_instances(params = {}) ⇒ Types::ListDeploymentInstancesOutput
BatchGetDeploymentTargets should be used instead because
it works with all compute types. ListDeploymentInstances throws an
exception if it is used with a compute platform other than
EC2/On-premises or Lambda.
Lists the instance for a deployment associated with the user or Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
566 |
# File 'sig/client.rbs', line 566
def list_deployment_instances: (
|
#list_deployment_targets(params = {}) ⇒ Types::ListDeploymentTargetsOutput
Returns an array of target IDs that are associated a deployment.
580 |
# File 'sig/client.rbs', line 580
def list_deployment_targets: (
|
#list_deployments(params = {}) ⇒ Types::ListDeploymentsOutput
Lists the deployments in a deployment group for an application registered with the user or Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
593 |
# File 'sig/client.rbs', line 593
def list_deployments: (
|
#list_git_hub_account_token_names(params = {}) ⇒ Types::ListGitHubAccountTokenNamesOutput
Lists the names of stored connections to GitHub accounts.
612 |
# File 'sig/client.rbs', line 612
def list_git_hub_account_token_names: (
|
#list_on_premises_instances(params = {}) ⇒ Types::ListOnPremisesInstancesOutput
Gets a list of names for one or more on-premises instances.
Unless otherwise specified, both registered and deregistered on-premises instance names are listed. To list only registered or deregistered on-premises instance names, use the registration status parameter.
623 |
# File 'sig/client.rbs', line 623
def list_on_premises_instances: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns a list of tags for the resource identified by a specified Amazon Resource Name (ARN). Tags are used to organize and categorize your CodeDeploy resources.
642 |
# File 'sig/client.rbs', line 642
def list_tags_for_resource: (
|
#put_lifecycle_event_hook_execution_status(params = {}) ⇒ Types::PutLifecycleEventHookExecutionStatusOutput
Sets the result of a Lambda validation function. The function
validates lifecycle hooks during a deployment that uses the Lambda or
Amazon ECS compute platform. For Lambda deployments, the available
lifecycle hooks are BeforeAllowTraffic and AfterAllowTraffic. For
Amazon ECS deployments, the available lifecycle hooks are
BeforeInstall, AfterInstall, AfterAllowTestTraffic,
BeforeAllowTraffic, and AfterAllowTraffic. Lambda validation
functions return Succeeded or Failed. For more information, see
AppSpec 'hooks' Section for an Lambda Deployment and AppSpec
'hooks' Section for an Amazon ECS Deployment.
653 |
# File 'sig/client.rbs', line 653
def put_lifecycle_event_hook_execution_status: (
|
#register_application_revision(params = {}) ⇒ Struct
Registers with CodeDeploy a revision for the specified application.
661 |
# File 'sig/client.rbs', line 661
def register_application_revision: (
|
#register_on_premises_instance(params = {}) ⇒ Struct
Registers an on-premises instance.
669 |
# File 'sig/client.rbs', line 669
def register_on_premises_instance: (
|
#remove_tags_from_on_premises_instances(params = {}) ⇒ Struct
Removes one or more tags from one or more on-premises instances.
677 |
# File 'sig/client.rbs', line 677
def remove_tags_from_on_premises_instances: (
|
#skip_wait_time_for_instance_termination(params = {}) ⇒ Struct
In a blue/green deployment, overrides any specified wait time and starts terminating instances immediately after the traffic routing is complete.
689 |
# File 'sig/client.rbs', line 689
def skip_wait_time_for_instance_termination: (
|
#stop_deployment(params = {}) ⇒ Types::StopDeploymentOutput
Attempts to stop an ongoing deployment.
700 |
# File 'sig/client.rbs', line 700
def stop_deployment: (
|
#tag_resource(params = {}) ⇒ Struct
Associates the list of tags in the input Tags parameter with the
resource identified by the ResourceArn input parameter.
710 |
# File 'sig/client.rbs', line 710
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Disassociates a resource from a list of tags. The resource is
identified by the ResourceArn input parameter. The tags are
identified by the list of keys in the TagKeys input parameter.
725 |
# File 'sig/client.rbs', line 725
def untag_resource: (
|
#update_application(params = {}) ⇒ Struct
Changes the name of an application.
732 |
# File 'sig/client.rbs', line 732
def update_application: (
|
#update_deployment_group(params = {}) ⇒ Types::UpdateDeploymentGroupOutput
Changes information about a deployment group.
743 |
# File 'sig/client.rbs', line 743
def update_deployment_group: (
|
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
Basic Usage
A waiter will call an API operation until:
- It is successful
- It enters a terminal state
- It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
Valid Waiters
The following table lists the valid waiter names, the operations they call,
and the default :delay and :max_attempts values.
| waiter_name | params | :delay | :max_attempts |
|---|---|---|---|
| deployment_successful | #get_deployment | 15 | 120 |
824 |
# File 'sig/client.rbs', line 824
def wait_until: (:deployment_successful waiter_name,
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3773 3774 3775 |
# File 'lib/aws-sdk-codedeploy/client.rb', line 3773 def waiter_names waiters.keys end |