Method: Aws::CodeDeploy::Client#create_application

Defined in:
lib/aws-sdk-codedeploy/client.rb

#create_application(params = {}) ⇒ Types::CreateApplicationOutput

Creates an application.

Examples:

Request syntax with placeholder values


resp = client.create_application({
  application_name: "ApplicationName", # required
  compute_platform: "Server", # accepts Server, Lambda, ECS
  tags: [
    {
      key: "Key",
      value: "Value",
    },
  ],
})

Response structure


resp.application_id #=> String

Parameters:

  • (defaults to: {})

    ({})

Options Hash (params):

  • :application_name (required, String)

    The name of the application. This name must be unique with the applicable IAM user or AWS account.

  • :compute_platform (String)

    The destination platform type for the deployment (Lambda, Server, or ECS).

  • :tags (Array<Types::Tag>)

    The metadata that you apply to CodeDeploy applications to help you organize and categorize them. Each tag consists of a key and an optional value, both of which you define.

Returns:

  • Returns a response object which responds to the following methods:

See Also:



1033
1034
1035
1036
# File 'lib/aws-sdk-codedeploy/client.rb', line 1033

def create_application(params = {}, options = {})
  req = build_request(:create_application, params)
  req.send_request(options)
end