Method: Aws::CodeDeploy::Client#create_deployment
- Defined in:
- lib/aws-sdk-codedeploy/client.rb
#create_deployment(params = {}) ⇒ Types::CreateDeploymentOutput
Deploys an application revision through the specified deployment group.
Examples:
Request syntax with placeholder values
Request syntax with placeholder values
resp = client.create_deployment({
application_name: "ApplicationName", # required
deployment_group_name: "DeploymentGroupName",
revision: {
revision_type: "S3", # accepts S3, GitHub, String, AppSpecContent
s3_location: {
bucket: "S3Bucket",
key: "S3Key",
bundle_type: "tar", # accepts tar, tgz, zip, YAML, JSON
version: "VersionId",
e_tag: "ETag",
},
git_hub_location: {
repository: "Repository",
commit_id: "CommitId",
},
string: {
content: "RawStringContent",
sha256: "RawStringSha256",
},
app_spec_content: {
content: "RawStringContent",
sha256: "RawStringSha256",
},
},
deployment_config_name: "DeploymentConfigName",
description: "Description",
ignore_application_stop_failures: false,
target_instances: {
tag_filters: [
{
key: "Key",
value: "Value",
type: "KEY_ONLY", # accepts KEY_ONLY, VALUE_ONLY, KEY_AND_VALUE
},
],
auto_scaling_groups: ["AutoScalingGroupName"],
ec2_tag_set: {
ec2_tag_set_list: [
[
{
key: "Key",
value: "Value",
type: "KEY_ONLY", # accepts KEY_ONLY, VALUE_ONLY, KEY_AND_VALUE
},
],
],
},
},
auto_rollback_configuration: {
enabled: false,
events: ["DEPLOYMENT_FAILURE"], # accepts DEPLOYMENT_FAILURE, DEPLOYMENT_STOP_ON_ALARM, DEPLOYMENT_STOP_ON_REQUEST
},
update_outdated_instances_only: false,
file_exists_behavior: "DISALLOW", # accepts DISALLOW, OVERWRITE, RETAIN
})
Response structure
Response structure
resp.deployment_id #=> String
Parameters:
-
params
(Hash)
(defaults to: {})
—
({})
Options Hash (params):
-
:application_name
(required, String)
—
The name of an AWS CodeDeploy application associated with the IAM user or AWS account.
-
:deployment_group_name
(String)
—
The name of the deployment group.
-
:revision
(Types::RevisionLocation)
—
The type and location of the revision to deploy.
-
:deployment_config_name
(String)
—
The name of a deployment configuration associated with the IAM user or AWS account.
If not specified, the value configured in the deployment group is used as the default. If the deployment group does not have a deployment configuration associated with it,
CodeDeployDefault.OneAtATimeis used by default. -
:description
(String)
—
A comment about the deployment.
-
:ignore_application_stop_failures
(Boolean)
—
If true, then if an
ApplicationStop,BeforeBlockTraffic, orAfterBlockTrafficdeployment lifecycle event to an instance fails, then the deployment continues to the next deployment lifecycle event. For example, ifApplicationStopfails, the deployment continues withDownloadBundle. IfBeforeBlockTrafficfails, the deployment continues withBlockTraffic. IfAfterBlockTrafficfails, the deployment continues withApplicationStop.If false or not specified, then if a lifecycle event fails during a deployment to an instance, that deployment fails. If deployment to that instance is part of an overall deployment and the number of healthy hosts is not less than the minimum number of healthy hosts, then a deployment to the next instance is attempted.
During a deployment, the AWS CodeDeploy agent runs the scripts specified for
ApplicationStop,BeforeBlockTraffic, andAfterBlockTrafficin the AppSpec file from the previous successful deployment. (All other scripts are run from the AppSpec file in the current deployment.) If one of these scripts contains an error and does not run successfully, the deployment can fail.If the cause of the failure is a script from the last successful deployment that will never run successfully, create a new deployment and use
ignoreApplicationStopFailuresto specify that theApplicationStop,BeforeBlockTraffic, andAfterBlockTrafficfailures should be ignored. -
:target_instances
(Types::TargetInstances)
—
Information about the instances that belong to the replacement environment in a blue/green deployment.
-
:auto_rollback_configuration
(Types::AutoRollbackConfiguration)
—
Configuration information for an automatic rollback that is added when a deployment is created.
-
:update_outdated_instances_only
(Boolean)
—
Indicates whether to deploy to all instances or only to instances that are not running the latest application revision.
-
:file_exists_behavior
(String)
—
Information about how AWS CodeDeploy handles files that already exist in a deployment target location but weren’t part of the previous successful deployment.
The
fileExistsBehaviorparameter takes any of the following values:-
DISALLOW: The deployment fails. This is also the default behavior if no option is specified.
-
OVERWRITE: The version of the file from the application revision currently being deployed replaces the version already on the instance.
-
RETAIN: The version of the file already on the instance is kept and used as part of the new deployment.
-
Returns:
-
(Types::CreateDeploymentOutput)
—
Returns a response object which responds to the following methods:
-
#deployment_id => String
-
See Also:
1191 1192 1193 1194 |
# File 'lib/aws-sdk-codedeploy/client.rb', line 1191 def create_deployment(params = {}, options = {}) req = build_request(:create_deployment, params) req.send_request(options) end |