Class: Aws::CodeDeploy::Types::BatchGetApplicationRevisionsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::BatchGetApplicationRevisionsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Represents the input of a BatchGetApplicationRevisions operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_name ⇒ String
The name of an CodeDeploy application about which to get revision information.
-
#revisions ⇒ Array<Types::RevisionLocation>
An array of
RevisionLocationobjects that specify information to get about the application revisions, including type and location.
Instance Attribute Details
#application_name ⇒ String
The name of an CodeDeploy application about which to get revision information.
257 258 259 260 261 262 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 257 class BatchGetApplicationRevisionsInput < Struct.new( :application_name, :revisions) SENSITIVE = [] include Aws::Structure end |
#revisions ⇒ Array<Types::RevisionLocation>
An array of RevisionLocation objects that specify information to get about the application revisions, including type and location. The maximum number of RevisionLocation objects you can specify is 25.
257 258 259 260 261 262 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 257 class BatchGetApplicationRevisionsInput < Struct.new( :application_name, :revisions) SENSITIVE = [] include Aws::Structure end |