Method: Aws::CodeDeploy::Types::CreateDeploymentConfigInput#minimum_healthy_hosts
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
#minimum_healthy_hosts ⇒ Types::MinimumHealthyHosts
The minimum number of healthy instances that should be available at any time during the deployment. There are two parameters expected in the input: type and value.
The type parameter takes either of the following values:
-
HOST_COUNT: The value parameter represents the minimum number of healthy instances as an absolute value.
-
FLEET_PERCENT: The value parameter represents the minimum number of healthy instances as a percentage of the total number of instances in the deployment. If you specify FLEET_PERCENT, at the start of the deployment, CodeDeploy converts the percentage to the equivalent number of instances and rounds up fractional instances.
The value parameter takes an integer.
For example, to set a minimum of 95% healthy instance, specify a type of FLEET_PERCENT and a value of 95.
788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 788 class CreateDeploymentConfigInput < Struct.new( :deployment_config_name, :minimum_healthy_hosts, :traffic_routing_config, :compute_platform, :zonal_config) SENSITIVE = [] include Aws::Structure end |