Class: Aws::CodeDeploy::Types::CreateDeploymentGroupInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::CreateDeploymentGroupInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Represents the input of a CreateDeploymentGroup operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alarm_configuration ⇒ Types::AlarmConfiguration
Information to add about Amazon CloudWatch alarms when the deployment group is created.
-
#application_name ⇒ String
The name of an CodeDeploy application associated with the user or Amazon Web Services account.
-
#auto_rollback_configuration ⇒ Types::AutoRollbackConfiguration
Configuration information for an automatic rollback that is added when a deployment group is created.
-
#auto_scaling_groups ⇒ Array<String>
A list of associated Amazon EC2 Auto Scaling groups.
-
#blue_green_deployment_configuration ⇒ Types::BlueGreenDeploymentConfiguration
Information about blue/green deployment options for a deployment group.
-
#deployment_config_name ⇒ String
If specified, the deployment configuration name can be either one of the predefined configurations provided with CodeDeploy or a custom deployment configuration that you create by calling the create deployment configuration operation.
-
#deployment_group_name ⇒ String
The name of a new deployment group for the specified application.
-
#deployment_style ⇒ Types::DeploymentStyle
Information about the type of deployment, in-place or blue/green, that you want to run and whether to route deployment traffic behind a load balancer.
-
#ec2_tag_filters ⇒ Array<Types::EC2TagFilter>
The Amazon EC2 tags on which to filter.
-
#ec2_tag_set ⇒ Types::EC2TagSet
Information about groups of tags applied to Amazon EC2 instances.
-
#ecs_services ⇒ Array<Types::ECSService>
The target Amazon ECS services in the deployment group.
-
#load_balancer_info ⇒ Types::LoadBalancerInfo
Information about the load balancer used in a deployment.
-
#on_premises_instance_tag_filters ⇒ Array<Types::TagFilter>
The on-premises instance tags on which to filter.
-
#on_premises_tag_set ⇒ Types::OnPremisesTagSet
Information about groups of tags applied to on-premises instances.
-
#outdated_instances_strategy ⇒ String
Indicates what happens when new Amazon EC2 instances are launched mid-deployment and do not receive the deployed application revision.
-
#service_role_arn ⇒ String
A service role Amazon Resource Name (ARN) that allows CodeDeploy to act on the user’s behalf when interacting with Amazon Web Services services.
-
#tags ⇒ Array<Types::Tag>
The metadata that you apply to CodeDeploy deployment groups to help you organize and categorize them.
-
#trigger_configurations ⇒ Array<Types::TriggerConfig>
Information about triggers to create when the deployment group is created.
Instance Attribute Details
#alarm_configuration ⇒ Types::AlarmConfiguration
Information to add about Amazon CloudWatch alarms when the deployment group is created.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 906 class CreateDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set, :tags) SENSITIVE = [] include Aws::Structure end |
#application_name ⇒ String
The name of an CodeDeploy application associated with the user or Amazon Web Services account.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 906 class CreateDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set, :tags) SENSITIVE = [] include Aws::Structure end |
#auto_rollback_configuration ⇒ Types::AutoRollbackConfiguration
Configuration information for an automatic rollback that is added when a deployment group is created.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 906 class CreateDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set, :tags) SENSITIVE = [] include Aws::Structure end |
#auto_scaling_groups ⇒ Array<String>
A list of associated Amazon EC2 Auto Scaling groups.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 906 class CreateDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set, :tags) SENSITIVE = [] include Aws::Structure end |
#blue_green_deployment_configuration ⇒ Types::BlueGreenDeploymentConfiguration
Information about blue/green deployment options for a deployment group.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 906 class CreateDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set, :tags) SENSITIVE = [] include Aws::Structure end |
#deployment_config_name ⇒ String
If specified, the deployment configuration name can be either one of the predefined configurations provided with CodeDeploy or a custom deployment configuration that you create by calling the create deployment configuration operation.
CodeDeployDefault.OneAtATime is the default deployment configuration. It is used if a configuration isn’t specified for the deployment or deployment group.
For more information about the predefined deployment configurations in CodeDeploy, see [Working with Deployment Configurations in CodeDeploy][1] in the *CodeDeploy User Guide*.
[1]: docs.aws.amazon.com/codedeploy/latest/userguide/deployment-configurations.html
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 906 class CreateDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set, :tags) SENSITIVE = [] include Aws::Structure end |
#deployment_group_name ⇒ String
The name of a new deployment group for the specified application.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 906 class CreateDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set, :tags) SENSITIVE = [] include Aws::Structure end |
#deployment_style ⇒ Types::DeploymentStyle
Information about the type of deployment, in-place or blue/green, that you want to run and whether to route deployment traffic behind a load balancer.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 906 class CreateDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set, :tags) SENSITIVE = [] include Aws::Structure end |
#ec2_tag_filters ⇒ Array<Types::EC2TagFilter>
The Amazon EC2 tags on which to filter. The deployment group includes Amazon EC2 instances with any of the specified tags. Cannot be used in the same call as ec2TagSet.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 906 class CreateDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set, :tags) SENSITIVE = [] include Aws::Structure end |
#ec2_tag_set ⇒ Types::EC2TagSet
Information about groups of tags applied to Amazon EC2 instances. The deployment group includes only Amazon EC2 instances identified by all the tag groups. Cannot be used in the same call as ec2TagFilters.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 906 class CreateDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set, :tags) SENSITIVE = [] include Aws::Structure end |
#ecs_services ⇒ Array<Types::ECSService>
The target Amazon ECS services in the deployment group. This applies only to deployment groups that use the Amazon ECS compute platform. A target Amazon ECS service is specified as an Amazon ECS cluster and service name pair using the format ‘<clustername>:<servicename>`.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 906 class CreateDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set, :tags) SENSITIVE = [] include Aws::Structure end |
#load_balancer_info ⇒ Types::LoadBalancerInfo
Information about the load balancer used in a deployment.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 906 class CreateDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set, :tags) SENSITIVE = [] include Aws::Structure end |
#on_premises_instance_tag_filters ⇒ Array<Types::TagFilter>
The on-premises instance tags on which to filter. The deployment group includes on-premises instances with any of the specified tags. Cannot be used in the same call as OnPremisesTagSet.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 906 class CreateDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set, :tags) SENSITIVE = [] include Aws::Structure end |
#on_premises_tag_set ⇒ Types::OnPremisesTagSet
Information about groups of tags applied to on-premises instances. The deployment group includes only on-premises instances identified by all of the tag groups. Cannot be used in the same call as onPremisesInstanceTagFilters.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 906 class CreateDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set, :tags) SENSITIVE = [] include Aws::Structure end |
#outdated_instances_strategy ⇒ String
Indicates what happens when new Amazon EC2 instances are launched mid-deployment and do not receive the deployed application revision.
If this option is set to UPDATE or is unspecified, CodeDeploy initiates one or more ‘auto-update outdated instances’ deployments to apply the deployed application revision to the new Amazon EC2 instances.
If this option is set to IGNORE, CodeDeploy does not initiate a deployment to update the new Amazon EC2 instances. This may result in instances having different revisions.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 906 class CreateDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set, :tags) SENSITIVE = [] include Aws::Structure end |
#service_role_arn ⇒ String
A service role Amazon Resource Name (ARN) that allows CodeDeploy to act on the user’s behalf when interacting with Amazon Web Services services.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 906 class CreateDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The metadata that you apply to CodeDeploy deployment groups to help you organize and categorize them. Each tag consists of a key and an optional value, both of which you define.
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 906 class CreateDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set, :tags) SENSITIVE = [] include Aws::Structure end |
#trigger_configurations ⇒ Array<Types::TriggerConfig>
Information about triggers to create when the deployment group is created. For examples, see [Create a Trigger for an CodeDeploy Event][1] in the *CodeDeploy User Guide*.
[1]: docs.aws.amazon.com/codedeploy/latest/userguide/how-to-notify-sns.html
906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 906 class CreateDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set, :tags) SENSITIVE = [] include Aws::Structure end |