Class: Aws::CodeDeploy::Types::DeleteDeploymentGroupInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::DeleteDeploymentGroupInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Represents the input of a DeleteDeploymentGroup operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_name ⇒ String
The name of an CodeDeploy application associated with the user or Amazon Web Services account.
-
#deployment_group_name ⇒ String
The name of a deployment group for the specified application.
Instance Attribute Details
#application_name ⇒ String
The name of an CodeDeploy application associated with the user or Amazon Web Services account.
1130 1131 1132 1133 1134 1135 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1130 class DeleteDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name) SENSITIVE = [] include Aws::Structure end |
#deployment_group_name ⇒ String
The name of a deployment group for the specified application.
1130 1131 1132 1133 1134 1135 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1130 class DeleteDeploymentGroupInput < Struct.new( :application_name, :deployment_group_name) SENSITIVE = [] include Aws::Structure end |