Class: Aws::CodeDeploy::Types::DeploymentGroupInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::DeploymentGroupInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Information about a deployment group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alarm_configuration ⇒ Types::AlarmConfiguration
A list of alarms associated with the deployment group.
-
#application_name ⇒ String
The application name.
-
#auto_rollback_configuration ⇒ Types::AutoRollbackConfiguration
Information about the automatic rollback configuration associated with the deployment group.
-
#auto_scaling_groups ⇒ Array<Types::AutoScalingGroup>
A list of associated Auto Scaling groups.
-
#blue_green_deployment_configuration ⇒ Types::BlueGreenDeploymentConfiguration
Information about blue/green deployment options for a deployment group.
-
#compute_platform ⇒ String
The destination platform type for the deployment (
Lambda,Server, orECS). -
#deployment_config_name ⇒ String
The deployment configuration name.
-
#deployment_group_id ⇒ String
The deployment group ID.
-
#deployment_group_name ⇒ String
The deployment group name.
-
#deployment_style ⇒ Types::DeploymentStyle
Information about the type of deployment, either in-place or blue/green, you want to run and whether to route deployment traffic behind a load balancer.
-
#ec2_tag_filters ⇒ Array<Types::EC2TagFilter>
The Amazon EC2 tags on which to filter.
-
#ec2_tag_set ⇒ Types::EC2TagSet
Information about groups of tags applied to an EC2 instance.
-
#ecs_services ⇒ Array<Types::ECSService>
The target Amazon ECS services in the deployment group.
-
#last_attempted_deployment ⇒ Types::LastDeploymentInfo
Information about the most recent attempted deployment to the deployment group.
-
#last_successful_deployment ⇒ Types::LastDeploymentInfo
Information about the most recent successful deployment to the deployment group.
-
#load_balancer_info ⇒ Types::LoadBalancerInfo
Information about the load balancer to use in a deployment.
-
#on_premises_instance_tag_filters ⇒ Array<Types::TagFilter>
The on-premises instance tags on which to filter.
-
#on_premises_tag_set ⇒ Types::OnPremisesTagSet
Information about groups of tags applied to an on-premises instance.
-
#service_role_arn ⇒ String
A service role Amazon Resource Name (ARN) that grants CodeDeploy permission to make calls to AWS services on your behalf.
-
#target_revision ⇒ Types::RevisionLocation
Information about the deployment group’s target revision, including type and location.
-
#trigger_configurations ⇒ Array<Types::TriggerConfig>
Information about triggers associated with the deployment group.
Instance Attribute Details
#alarm_configuration ⇒ Types::AlarmConfiguration
A list of alarms associated with the deployment group.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#application_name ⇒ String
The application name.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#auto_rollback_configuration ⇒ Types::AutoRollbackConfiguration
Information about the automatic rollback configuration associated with the deployment group.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#auto_scaling_groups ⇒ Array<Types::AutoScalingGroup>
A list of associated Auto Scaling groups.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#blue_green_deployment_configuration ⇒ Types::BlueGreenDeploymentConfiguration
Information about blue/green deployment options for a deployment group.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#compute_platform ⇒ String
The destination platform type for the deployment (Lambda, Server, or ECS).
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#deployment_config_name ⇒ String
The deployment configuration name.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#deployment_group_id ⇒ String
The deployment group ID.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#deployment_group_name ⇒ String
The deployment group name.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#deployment_style ⇒ Types::DeploymentStyle
Information about the type of deployment, either in-place or blue/green, you want to run and whether to route deployment traffic behind a load balancer.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#ec2_tag_filters ⇒ Array<Types::EC2TagFilter>
The Amazon EC2 tags on which to filter. The deployment group includes EC2 instances with any of the specified tags.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#ec2_tag_set ⇒ Types::EC2TagSet
Information about groups of tags applied to an EC2 instance. The deployment group includes only EC2 instances identified by all of the tag groups. Cannot be used in the same call as ec2TagFilters.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#ecs_services ⇒ Array<Types::ECSService>
The target Amazon ECS services in the deployment group. This applies only to deployment groups that use the Amazon ECS compute platform. A target Amazon ECS service is specified as an Amazon ECS cluster and service name pair using the format ‘<clustername>:<servicename>`.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#last_attempted_deployment ⇒ Types::LastDeploymentInfo
Information about the most recent attempted deployment to the deployment group.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#last_successful_deployment ⇒ Types::LastDeploymentInfo
Information about the most recent successful deployment to the deployment group.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#load_balancer_info ⇒ Types::LoadBalancerInfo
Information about the load balancer to use in a deployment.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#on_premises_instance_tag_filters ⇒ Array<Types::TagFilter>
The on-premises instance tags on which to filter. The deployment group includes on-premises instances with any of the specified tags.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#on_premises_tag_set ⇒ Types::OnPremisesTagSet
Information about groups of tags applied to an on-premises instance. The deployment group includes only on-premises instances identified by all the tag groups. Cannot be used in the same call as onPremisesInstanceTagFilters.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#service_role_arn ⇒ String
A service role Amazon Resource Name (ARN) that grants CodeDeploy permission to make calls to AWS services on your behalf. For more information, see [Create a Service Role for AWS CodeDeploy] in the *AWS CodeDeploy User Guide*.
[1]: docs.aws.amazon.com/codedeploy/latest/userguide/getting-started-create-service-role.html
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#target_revision ⇒ Types::RevisionLocation
Information about the deployment group’s target revision, including type and location.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |
#trigger_configurations ⇒ Array<Types::TriggerConfig>
Information about triggers associated with the deployment group.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1800 class DeploymentGroupInfo < Struct.new( :application_name, :deployment_group_id, :deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :target_revision, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :last_successful_deployment, :last_attempted_deployment, :ec2_tag_set, :on_premises_tag_set, :compute_platform, :ecs_services) SENSITIVE = [] include Aws::Structure end |