Method: Aws::CodeDeploy::Types::DeploymentInfo#previous_revision

Defined in:
lib/aws-sdk-codedeploy/types.rb

#previous_revisionTypes::RevisionLocation

Information about the application revision that was deployed to the deployment group before the most recent successful deployment.



1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
# File 'lib/aws-sdk-codedeploy/types.rb', line 1758

class DeploymentInfo < Struct.new(
  :application_name,
  :deployment_group_name,
  :deployment_config_name,
  :deployment_id,
  :previous_revision,
  :revision,
  :status,
  :error_information,
  :create_time,
  :start_time,
  :complete_time,
  :deployment_overview,
  :description,
  :creator,
  :ignore_application_stop_failures,
  :auto_rollback_configuration,
  :update_outdated_instances_only,
  :rollback_info,
  :deployment_style,
  :target_instances,
  :instance_termination_wait_time_started,
  :blue_green_deployment_configuration,
  :load_balancer_info,
  :additional_deployment_status_info,
  :file_exists_behavior,
  :deployment_status_messages,
  :compute_platform,
  :external_id,
  :related_deployments,
  :override_alarm_configuration)
  SENSITIVE = []
  include Aws::Structure
end