Class: Aws::CodeDeploy::Types::DeploymentTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::DeploymentTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Information about the deployment target.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_formation_target ⇒ Types::CloudFormationTarget
Information about the target to be updated by an CloudFormation blue/green deployment.
-
#deployment_target_type ⇒ String
The deployment type that is specific to the deployment’s compute platform or deployments initiated by a CloudFormation stack update.
-
#ecs_target ⇒ Types::ECSTarget
Information about the target for a deployment that uses the Amazon ECS compute platform.
-
#instance_target ⇒ Types::InstanceTarget
Information about the target for a deployment that uses the EC2/On-premises compute platform.
-
#lambda_target ⇒ Types::LambdaTarget
Information about the target for a deployment that uses the Lambda compute platform.
Instance Attribute Details
#cloud_formation_target ⇒ Types::CloudFormationTarget
Information about the target to be updated by an CloudFormation blue/green deployment. This target type is used for all deployments initiated by a CloudFormation stack update.
1860 1861 1862 1863 1864 1865 1866 1867 1868 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1860 class DeploymentTarget < Struct.new( :deployment_target_type, :instance_target, :lambda_target, :ecs_target, :cloud_formation_target) SENSITIVE = [] include Aws::Structure end |
#deployment_target_type ⇒ String
The deployment type that is specific to the deployment’s compute platform or deployments initiated by a CloudFormation stack update.
1860 1861 1862 1863 1864 1865 1866 1867 1868 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1860 class DeploymentTarget < Struct.new( :deployment_target_type, :instance_target, :lambda_target, :ecs_target, :cloud_formation_target) SENSITIVE = [] include Aws::Structure end |
#ecs_target ⇒ Types::ECSTarget
Information about the target for a deployment that uses the Amazon ECS compute platform.
1860 1861 1862 1863 1864 1865 1866 1867 1868 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1860 class DeploymentTarget < Struct.new( :deployment_target_type, :instance_target, :lambda_target, :ecs_target, :cloud_formation_target) SENSITIVE = [] include Aws::Structure end |
#instance_target ⇒ Types::InstanceTarget
Information about the target for a deployment that uses the EC2/On-premises compute platform.
1860 1861 1862 1863 1864 1865 1866 1867 1868 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1860 class DeploymentTarget < Struct.new( :deployment_target_type, :instance_target, :lambda_target, :ecs_target, :cloud_formation_target) SENSITIVE = [] include Aws::Structure end |
#lambda_target ⇒ Types::LambdaTarget
Information about the target for a deployment that uses the Lambda compute platform.
1860 1861 1862 1863 1864 1865 1866 1867 1868 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1860 class DeploymentTarget < Struct.new( :deployment_target_type, :instance_target, :lambda_target, :ecs_target, :cloud_formation_target) SENSITIVE = [] include Aws::Structure end |