Class: Aws::CodeDeploy::Types::ECSService

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codedeploy/types.rb

Overview

Contains the service and cluster names used to identify an Amazon ECS deployment's target.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_nameString

The name of the cluster that the Amazon ECS service is associated with.

Returns:

  • (String)


2142
2143
2144
2145
2146
2147
# File 'lib/aws-sdk-codedeploy/types.rb', line 2142

class ECSService < Struct.new(
  :service_name,
  :cluster_name)
  SENSITIVE = []
  include Aws::Structure
end

#service_nameString

The name of the target Amazon ECS service.

Returns:

  • (String)


2142
2143
2144
2145
2146
2147
# File 'lib/aws-sdk-codedeploy/types.rb', line 2142

class ECSService < Struct.new(
  :service_name,
  :cluster_name)
  SENSITIVE = []
  include Aws::Structure
end