Class: Aws::CodeDeploy::Types::GenericRevisionInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::GenericRevisionInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Information about an application revision.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deployment_groups ⇒ Array<String>
The deployment groups for which this is the current target revision.
-
#description ⇒ String
A comment about the revision.
-
#first_used_time ⇒ Time
When the revision was first used by CodeDeploy.
-
#last_used_time ⇒ Time
When the revision was last used by CodeDeploy.
-
#register_time ⇒ Time
When the revision was registered with CodeDeploy.
Instance Attribute Details
#deployment_groups ⇒ Array<String>
The deployment groups for which this is the current target revision.
2269 2270 2271 2272 2273 2274 2275 2276 2277 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2269 class GenericRevisionInfo < Struct.new( :description, :deployment_groups, :first_used_time, :last_used_time, :register_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A comment about the revision.
2269 2270 2271 2272 2273 2274 2275 2276 2277 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2269 class GenericRevisionInfo < Struct.new( :description, :deployment_groups, :first_used_time, :last_used_time, :register_time) SENSITIVE = [] include Aws::Structure end |
#first_used_time ⇒ Time
When the revision was first used by CodeDeploy.
2269 2270 2271 2272 2273 2274 2275 2276 2277 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2269 class GenericRevisionInfo < Struct.new( :description, :deployment_groups, :first_used_time, :last_used_time, :register_time) SENSITIVE = [] include Aws::Structure end |
#last_used_time ⇒ Time
When the revision was last used by CodeDeploy.
2269 2270 2271 2272 2273 2274 2275 2276 2277 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2269 class GenericRevisionInfo < Struct.new( :description, :deployment_groups, :first_used_time, :last_used_time, :register_time) SENSITIVE = [] include Aws::Structure end |
#register_time ⇒ Time
When the revision was registered with CodeDeploy.
2269 2270 2271 2272 2273 2274 2275 2276 2277 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2269 class GenericRevisionInfo < Struct.new( :description, :deployment_groups, :first_used_time, :last_used_time, :register_time) SENSITIVE = [] include Aws::Structure end |