Class: Aws::CodeDeploy::Types::GetApplicationRevisionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::GetApplicationRevisionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Note:
When making an API call, you may pass GetApplicationRevisionInput data as a hash:
{
application_name: "ApplicationName", # required
revision: { # required
revision_type: "S3", # accepts S3, GitHub, String, AppSpecContent
s3_location: {
bucket: "S3Bucket",
key: "S3Key",
bundle_type: "tar", # accepts tar, tgz, zip, YAML, JSON
version: "VersionId",
e_tag: "ETag",
},
git_hub_location: {
repository: "Repository",
commit_id: "CommitId",
},
string: {
content: "RawStringContent",
sha256: "RawStringSha256",
},
app_spec_content: {
content: "RawStringContent",
sha256: "RawStringSha256",
},
},
}
Represents the input of a GetApplicationRevision operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_name ⇒ String
The name of the application that corresponds to the revision.
-
#revision ⇒ Types::RevisionLocation
Information about the application revision to get, including type and location.
Instance Attribute Details
#application_name ⇒ String
The name of the application that corresponds to the revision.
2763 2764 2765 2766 2767 2768 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2763 class GetApplicationRevisionInput < Struct.new( :application_name, :revision) SENSITIVE = [] include Aws::Structure end |
#revision ⇒ Types::RevisionLocation
Information about the application revision to get, including type and location.
2763 2764 2765 2766 2767 2768 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2763 class GetApplicationRevisionInput < Struct.new( :application_name, :revision) SENSITIVE = [] include Aws::Structure end |