Class: Aws::CodeDeploy::Types::GetDeploymentConfigInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::GetDeploymentConfigInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Note:
When making an API call, you may pass GetDeploymentConfigInput data as a hash:
{
deployment_config_name: "DeploymentConfigName", # required
}
Represents the input of a GetDeploymentConfig operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deployment_config_name ⇒ String
The name of a deployment configuration associated with the IAM user or AWS account.
Instance Attribute Details
#deployment_config_name ⇒ String
The name of a deployment configuration associated with the IAM user or AWS account.
2848 2849 2850 2851 2852 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2848 class GetDeploymentConfigInput < Struct.new( :deployment_config_name) SENSITIVE = [] include Aws::Structure end |