Class: Aws::CodeDeploy::Types::GetDeploymentInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::GetDeploymentInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Represents the input of a GetDeployment operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deployment_id ⇒ String
The unique ID of a deployment associated with the user or Amazon Web Services account.
Instance Attribute Details
#deployment_id ⇒ String
The unique ID of a deployment associated with the user or Amazon Web Services account.
2515 2516 2517 2518 2519 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2515 class GetDeploymentInput < Struct.new( :deployment_id) SENSITIVE = [] include Aws::Structure end |