Class: Aws::CodeDeploy::Types::GetDeploymentTargetOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::GetDeploymentTargetOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deployment_target ⇒ Types::DeploymentTarget
A deployment target that contains information about a deployment such as its status, lifecycle events, and when it was last updated.
Instance Attribute Details
#deployment_target ⇒ Types::DeploymentTarget
A deployment target that contains information about a deployment
such as its status, lifecycle events, and when it was last updated.
It also contains metadata about the deployment target. The
deployment target metadata depends on the deployment target's type
(instanceTarget, lambdaTarget, or ecsTarget).
2595 2596 2597 2598 2599 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2595 class GetDeploymentTargetOutput < Struct.new( :deployment_target) SENSITIVE = [] include Aws::Structure end |