Class: Aws::CodeDeploy::Types::LambdaFunctionInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codedeploy/types.rb

Overview

Information about a Lambda function specified in a deployment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#current_versionString

The version of a Lambda function that production traffic points to.

Returns:



3770
3771
3772
3773
3774
3775
3776
3777
3778
# File 'lib/aws-sdk-codedeploy/types.rb', line 3770

class LambdaFunctionInfo < Struct.new(
  :function_name,
  :function_alias,
  :current_version,
  :target_version,
  :target_version_weight)
  SENSITIVE = []
  include Aws::Structure
end

#function_aliasString

The alias of a Lambda function. For more information, see [AWS Lambda Function Aliases][1] in the *AWS Lambda Developer Guide*.

[1]: docs.aws.amazon.com/lambda/latest/dg/aliases-intro.html

Returns:



3770
3771
3772
3773
3774
3775
3776
3777
3778
# File 'lib/aws-sdk-codedeploy/types.rb', line 3770

class LambdaFunctionInfo < Struct.new(
  :function_name,
  :function_alias,
  :current_version,
  :target_version,
  :target_version_weight)
  SENSITIVE = []
  include Aws::Structure
end

#function_nameString

The name of a Lambda function.

Returns:



3770
3771
3772
3773
3774
3775
3776
3777
3778
# File 'lib/aws-sdk-codedeploy/types.rb', line 3770

class LambdaFunctionInfo < Struct.new(
  :function_name,
  :function_alias,
  :current_version,
  :target_version,
  :target_version_weight)
  SENSITIVE = []
  include Aws::Structure
end

#target_versionString

The version of a Lambda function that production traffic points to after the Lambda function is deployed.

Returns:



3770
3771
3772
3773
3774
3775
3776
3777
3778
# File 'lib/aws-sdk-codedeploy/types.rb', line 3770

class LambdaFunctionInfo < Struct.new(
  :function_name,
  :function_alias,
  :current_version,
  :target_version,
  :target_version_weight)
  SENSITIVE = []
  include Aws::Structure
end

#target_version_weightFloat

The percentage of production traffic that the target version of a Lambda function receives.

Returns:



3770
3771
3772
3773
3774
3775
3776
3777
3778
# File 'lib/aws-sdk-codedeploy/types.rb', line 3770

class LambdaFunctionInfo < Struct.new(
  :function_name,
  :function_alias,
  :current_version,
  :target_version,
  :target_version_weight)
  SENSITIVE = []
  include Aws::Structure
end