Class: Aws::CodeDeploy::Types::ListApplicationsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::ListApplicationsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Note:
When making an API call, you may pass ListApplicationsInput data as a hash:
{
next_token: "NextToken",
}
Represents the input of a ListApplications operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
An identifier returned from the previous list applications call.
Instance Attribute Details
#next_token ⇒ String
An identifier returned from the previous list applications call. It can be used to return the next set of applications in the list.
4022 4023 4024 4025 4026 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4022 class ListApplicationsInput < Struct.new( :next_token) SENSITIVE = [] include Aws::Structure end |