Class: Aws::CodeDeploy::Types::ListApplicationsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::ListApplicationsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Represents the output of a ListApplications operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#applications ⇒ Array<String>
A list of application names.
-
#next_token ⇒ String
If a large amount of information is returned, an identifier is also returned.
Instance Attribute Details
#applications ⇒ Array<String>
A list of application names.
4073 4074 4075 4076 4077 4078 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4073 class ListApplicationsOutput < Struct.new( :applications, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If a large amount of information is returned, an identifier is also returned. It can be used in a subsequent list applications call to return the next set of applications in the list.
4073 4074 4075 4076 4077 4078 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4073 class ListApplicationsOutput < Struct.new( :applications, :next_token) SENSITIVE = [] include Aws::Structure end |