Class: Aws::CodeDeploy::Types::ListDeploymentGroupsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::ListDeploymentGroupsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Represents the input of a ListDeploymentGroups operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_name ⇒ String
The name of an CodeDeploy application associated with the user or Amazon Web Services account.
-
#next_token ⇒ String
An identifier returned from the previous list deployment groups call.
Instance Attribute Details
#application_name ⇒ String
The name of an CodeDeploy application associated with the user or Amazon Web Services account.
3703 3704 3705 3706 3707 3708 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 3703 class ListDeploymentGroupsInput < Struct.new( :application_name, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An identifier returned from the previous list deployment groups call. It can be used to return the next set of deployment groups in the list.
3703 3704 3705 3706 3707 3708 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 3703 class ListDeploymentGroupsInput < Struct.new( :application_name, :next_token) SENSITIVE = [] include Aws::Structure end |