Class: Aws::CodeDeploy::Types::ListDeploymentInstancesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::ListDeploymentInstancesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Represents the input of a ListDeploymentInstances operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deployment_id ⇒ String
The unique ID of a deployment.
-
#instance_status_filter ⇒ Array<String>
A subset of instances to list by status:.
-
#instance_type_filter ⇒ Array<String>
The set of instances in a blue/green deployment, either those in the original environment ("BLUE") or those in the replacement environment ("GREEN"), for which you want to view instance information.
-
#next_token ⇒ String
An identifier returned from the previous list deployment instances call.
Instance Attribute Details
#deployment_id ⇒ String
The unique ID of a deployment.
3775 3776 3777 3778 3779 3780 3781 3782 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 3775 class ListDeploymentInstancesInput < Struct.new( :deployment_id, :next_token, :instance_status_filter, :instance_type_filter) SENSITIVE = [] include Aws::Structure end |
#instance_status_filter ⇒ Array<String>
A subset of instances to list by status:
-
Pending: Include those instances with pending deployments. -
InProgress: Include those instances where deployments are still in progress. -
Succeeded: Include those instances with successful deployments. -
Failed: Include those instances with failed deployments. -
Skipped: Include those instances with skipped deployments. -
Unknown: Include those instances with deployments in an unknown state.
3775 3776 3777 3778 3779 3780 3781 3782 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 3775 class ListDeploymentInstancesInput < Struct.new( :deployment_id, :next_token, :instance_status_filter, :instance_type_filter) SENSITIVE = [] include Aws::Structure end |
#instance_type_filter ⇒ Array<String>
The set of instances in a blue/green deployment, either those in the original environment ("BLUE") or those in the replacement environment ("GREEN"), for which you want to view instance information.
3775 3776 3777 3778 3779 3780 3781 3782 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 3775 class ListDeploymentInstancesInput < Struct.new( :deployment_id, :next_token, :instance_status_filter, :instance_type_filter) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An identifier returned from the previous list deployment instances call. It can be used to return the next set of deployment instances in the list.
3775 3776 3777 3778 3779 3780 3781 3782 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 3775 class ListDeploymentInstancesInput < Struct.new( :deployment_id, :next_token, :instance_status_filter, :instance_type_filter) SENSITIVE = [] include Aws::Structure end |