Class: Aws::CodeDeploy::Types::ListDeploymentTargetsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::ListDeploymentTargetsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If a large amount of information is returned, a token identifier is also returned.
-
#target_ids ⇒ Array<String>
The unique IDs of deployment targets.
Instance Attribute Details
#next_token ⇒ String
If a large amount of information is returned, a token identifier is also returned. It can be used in a subsequent ListDeploymentTargets call to return the next set of deployment targets in the list.
3721 3722 3723 3724 3725 3726 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 3721 class ListDeploymentTargetsOutput < Struct.new( :target_ids, :next_token) SENSITIVE = [] include Aws::Structure end |
#target_ids ⇒ Array<String>
The unique IDs of deployment targets.
3721 3722 3723 3724 3725 3726 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 3721 class ListDeploymentTargetsOutput < Struct.new( :target_ids, :next_token) SENSITIVE = [] include Aws::Structure end |