Class: Aws::CodeDeploy::Types::ListDeploymentsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::ListDeploymentsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Represents the input of a ListDeployments operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_name ⇒ String
The name of an CodeDeploy application associated with the user or Amazon Web Services account.
-
#create_time_range ⇒ Types::TimeRange
A time range (start and end) for returning a subset of the list of deployments.
-
#deployment_group_name ⇒ String
The name of a deployment group for the specified application.
-
#external_id ⇒ String
The unique ID of an external resource for returning deployments linked to the external resource.
-
#include_only_statuses ⇒ Array<String>
A subset of deployments to list by status:.
-
#next_token ⇒ String
An identifier returned from the previous list deployments call.
Instance Attribute Details
#application_name ⇒ String
The name of an CodeDeploy application associated with the user or Amazon Web Services account.
applicationName is specified, then deploymentGroupName must
be specified. If it is not specified, then deploymentGroupName
must not be specified.
3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 3913 class ListDeploymentsInput < Struct.new( :application_name, :deployment_group_name, :external_id, :include_only_statuses, :create_time_range, :next_token) SENSITIVE = [] include Aws::Structure end |
#create_time_range ⇒ Types::TimeRange
A time range (start and end) for returning a subset of the list of deployments.
3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 3913 class ListDeploymentsInput < Struct.new( :application_name, :deployment_group_name, :external_id, :include_only_statuses, :create_time_range, :next_token) SENSITIVE = [] include Aws::Structure end |
#deployment_group_name ⇒ String
The name of a deployment group for the specified application.
deploymentGroupName is specified, then applicationName must
be specified. If it is not specified, then applicationName must
not be specified.
3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 3913 class ListDeploymentsInput < Struct.new( :application_name, :deployment_group_name, :external_id, :include_only_statuses, :create_time_range, :next_token) SENSITIVE = [] include Aws::Structure end |
#external_id ⇒ String
The unique ID of an external resource for returning deployments linked to the external resource.
3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 3913 class ListDeploymentsInput < Struct.new( :application_name, :deployment_group_name, :external_id, :include_only_statuses, :create_time_range, :next_token) SENSITIVE = [] include Aws::Structure end |
#include_only_statuses ⇒ Array<String>
A subset of deployments to list by status:
-
Created: Include created deployments in the resulting list. -
Queued: Include queued deployments in the resulting list. -
In Progress: Include in-progress deployments in the resulting list. -
Succeeded: Include successful deployments in the resulting list. -
Failed: Include failed deployments in the resulting list. -
Stopped: Include stopped deployments in the resulting list.
3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 3913 class ListDeploymentsInput < Struct.new( :application_name, :deployment_group_name, :external_id, :include_only_statuses, :create_time_range, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An identifier returned from the previous list deployments call. It can be used to return the next set of deployments in the list.
3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 3913 class ListDeploymentsInput < Struct.new( :application_name, :deployment_group_name, :external_id, :include_only_statuses, :create_time_range, :next_token) SENSITIVE = [] include Aws::Structure end |