Class: Aws::CodeDeploy::Types::ListTagsForResourceInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codedeploy/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

An identifier returned from the previous ListTagsForResource call. It can be used to return the next set of applications in the list.

Returns:

  • (String)


3922
3923
3924
3925
3926
3927
# File 'lib/aws-sdk-codedeploy/types.rb', line 3922

class ListTagsForResourceInput < Struct.new(
  :resource_arn,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

The ARN of a CodeDeploy resource. ListTagsForResource returns all the tags associated with the resource that is identified by the ResourceArn.

Returns:

  • (String)


3922
3923
3924
3925
3926
3927
# File 'lib/aws-sdk-codedeploy/types.rb', line 3922

class ListTagsForResourceInput < Struct.new(
  :resource_arn,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end