Class: Aws::CodeDeploy::Types::ListTagsForResourceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::ListTagsForResourceOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If a large amount of information is returned, an identifier is also returned.
-
#tags ⇒ Array<Types::Tag>
A list of tags returned by
ListTagsForResource.
Instance Attribute Details
#next_token ⇒ String
If a large amount of information is returned, an identifier is also returned. It can be used in a subsequent list application revisions call to return the next set of application revisions in the list.
3943 3944 3945 3946 3947 3948 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 3943 class ListTagsForResourceOutput < Struct.new( :tags, :next_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags returned by ListTagsForResource. The tags are associated with the resource identified by the input ResourceArn parameter.
3943 3944 3945 3946 3947 3948 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 3943 class ListTagsForResourceOutput < Struct.new( :tags, :next_token) SENSITIVE = [] include Aws::Structure end |