Class: Aws::CodeDeploy::Types::OnPremisesTagSet
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::OnPremisesTagSet
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Information about groups of on-premises instance tags.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#on_premises_tag_set_list ⇒ Array<Array<Types::TagFilter>>
A list that contains other lists of on-premises instance tag groups.
Instance Attribute Details
#on_premises_tag_set_list ⇒ Array<Array<Types::TagFilter>>
A list that contains other lists of on-premises instance tag groups. For an instance to be included in the deployment group, it must be identified by all of the tag groups in the list.
4075 4076 4077 4078 4079 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4075 class OnPremisesTagSet < Struct.new( :on_premises_tag_set_list) SENSITIVE = [] include Aws::Structure end |