Class: Aws::CodeDeploy::Types::PutLifecycleEventHookExecutionStatusInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::PutLifecycleEventHookExecutionStatusInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Note:
When making an API call, you may pass PutLifecycleEventHookExecutionStatusInput data as a hash:
{
deployment_id: "DeploymentId",
lifecycle_event_hook_execution_id: "LifecycleEventHookExecutionId",
status: "Pending", # accepts Pending, InProgress, Succeeded, Failed, Skipped, Unknown
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deployment_id ⇒ String
The unique ID of a deployment.
-
#lifecycle_event_hook_execution_id ⇒ String
The execution ID of a deployment’s lifecycle hook.
-
#status ⇒ String
The result of a Lambda function that validates a deployment lifecycle event.
Instance Attribute Details
#deployment_id ⇒ String
The unique ID of a deployment. Pass this ID to a Lambda function that validates a deployment lifecycle event.
4793 4794 4795 4796 4797 4798 4799 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4793 class PutLifecycleEventHookExecutionStatusInput < Struct.new( :deployment_id, :lifecycle_event_hook_execution_id, :status) SENSITIVE = [] include Aws::Structure end |
#lifecycle_event_hook_execution_id ⇒ String
The execution ID of a deployment’s lifecycle hook. A deployment lifecycle hook is specified in the hooks section of the AppSpec file.
4793 4794 4795 4796 4797 4798 4799 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4793 class PutLifecycleEventHookExecutionStatusInput < Struct.new( :deployment_id, :lifecycle_event_hook_execution_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The result of a Lambda function that validates a deployment lifecycle event. Succeeded and Failed are the only valid values for status.
4793 4794 4795 4796 4797 4798 4799 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4793 class PutLifecycleEventHookExecutionStatusInput < Struct.new( :deployment_id, :lifecycle_event_hook_execution_id, :status) SENSITIVE = [] include Aws::Structure end |