Class: Aws::CodeDeploy::Types::RegisterApplicationRevisionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::RegisterApplicationRevisionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Represents the input of a RegisterApplicationRevision operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_name ⇒ String
The name of an CodeDeploy application associated with the user or Amazon Web Services account.
-
#description ⇒ String
A comment about the revision.
-
#revision ⇒ Types::RevisionLocation
Information about the application revision to register, including type and location.
Instance Attribute Details
#application_name ⇒ String
The name of an CodeDeploy application associated with the user or Amazon Web Services account.
4169 4170 4171 4172 4173 4174 4175 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4169 class RegisterApplicationRevisionInput < Struct.new( :application_name, :description, :revision) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A comment about the revision.
4169 4170 4171 4172 4173 4174 4175 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4169 class RegisterApplicationRevisionInput < Struct.new( :application_name, :description, :revision) SENSITIVE = [] include Aws::Structure end |
#revision ⇒ Types::RevisionLocation
Information about the application revision to register, including type and location.
4169 4170 4171 4172 4173 4174 4175 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4169 class RegisterApplicationRevisionInput < Struct.new( :application_name, :description, :revision) SENSITIVE = [] include Aws::Structure end |