Class: Aws::CodeDeploy::Types::S3Location
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::S3Location
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Information about the location of application artifacts stored in Amazon S3.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the Amazon S3 bucket where the application revision is stored.
-
#bundle_type ⇒ String
The file type of the application revision.
-
#e_tag ⇒ String
The ETag of the Amazon S3 object that represents the bundled artifacts for the application revision.
-
#key ⇒ String
The name of the Amazon S3 object that represents the bundled artifacts for the application revision.
-
#version ⇒ String
A specific version of the Amazon S3 object that represents the bundled artifacts for the application revision.
Instance Attribute Details
#bucket ⇒ String
The name of the Amazon S3 bucket where the application revision is stored.
4566 4567 4568 4569 4570 4571 4572 4573 4574 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4566 class S3Location < Struct.new( :bucket, :key, :bundle_type, :version, :e_tag) SENSITIVE = [] include Aws::Structure end |
#bundle_type ⇒ String
The file type of the application revision. Must be one of the following:
-
tar: A tar archive file. -
tgz: A compressed tar archive file. -
zip: A zip archive file. -
YAML: A YAML-formatted file. -
JSON: A JSON-formatted file.
4566 4567 4568 4569 4570 4571 4572 4573 4574 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4566 class S3Location < Struct.new( :bucket, :key, :bundle_type, :version, :e_tag) SENSITIVE = [] include Aws::Structure end |
#e_tag ⇒ String
The ETag of the Amazon S3 object that represents the bundled artifacts for the application revision.
If the ETag is not specified as an input parameter, ETag validation of the object is skipped.
4566 4567 4568 4569 4570 4571 4572 4573 4574 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4566 class S3Location < Struct.new( :bucket, :key, :bundle_type, :version, :e_tag) SENSITIVE = [] include Aws::Structure end |
#key ⇒ String
The name of the Amazon S3 object that represents the bundled artifacts for the application revision.
4566 4567 4568 4569 4570 4571 4572 4573 4574 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4566 class S3Location < Struct.new( :bucket, :key, :bundle_type, :version, :e_tag) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
A specific version of the Amazon S3 object that represents the bundled artifacts for the application revision.
If the version is not specified, the system uses the most recent version by default.
4566 4567 4568 4569 4570 4571 4572 4573 4574 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4566 class S3Location < Struct.new( :bucket, :key, :bundle_type, :version, :e_tag) SENSITIVE = [] include Aws::Structure end |