Class: Aws::CodeDeploy::Types::StopDeploymentInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::StopDeploymentInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Represents the input of a StopDeployment operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_rollback_enabled ⇒ Boolean
Indicates, when a deployment is stopped, whether instances that have been updated should be rolled back to the previous version of the application revision.
-
#deployment_id ⇒ String
The unique ID of a deployment.
Instance Attribute Details
#auto_rollback_enabled ⇒ Boolean
Indicates, when a deployment is stopped, whether instances that have been updated should be rolled back to the previous version of the application revision.
4455 4456 4457 4458 4459 4460 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4455 class StopDeploymentInput < Struct.new( :deployment_id, :auto_rollback_enabled) SENSITIVE = [] include Aws::Structure end |
#deployment_id ⇒ String
The unique ID of a deployment.
4455 4456 4457 4458 4459 4460 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4455 class StopDeploymentInput < Struct.new( :deployment_id, :auto_rollback_enabled) SENSITIVE = [] include Aws::Structure end |