Class: Aws::CodeDeploy::Types::TimeBasedCanary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codedeploy/types.rb

Overview

Note:

When making an API call, you may pass TimeBasedCanary data as a hash:

{
  canary_percentage: 1,
  canary_interval: 1,
}

A configuration that shifts traffic from one version of a Lambda function or ECS task set to another in two increments. The original and target Lambda function versions or ECS task sets are specified in the deployment’s AppSpec file.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#canary_intervalInteger

The number of minutes between the first and second traffic shifts of a TimeBasedCanary deployment.

Returns:

  • (Integer)


5563
5564
5565
5566
5567
5568
# File 'lib/aws-sdk-codedeploy/types.rb', line 5563

class TimeBasedCanary < Struct.new(
  :canary_percentage,
  :canary_interval)
  SENSITIVE = []
  include Aws::Structure
end

#canary_percentageInteger

The percentage of traffic to shift in the first increment of a TimeBasedCanary deployment.

Returns:

  • (Integer)


5563
5564
5565
5566
5567
5568
# File 'lib/aws-sdk-codedeploy/types.rb', line 5563

class TimeBasedCanary < Struct.new(
  :canary_percentage,
  :canary_interval)
  SENSITIVE = []
  include Aws::Structure
end