Class: Aws::CodeDeploy::Types::TrafficRoutingConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::TrafficRoutingConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
The configuration that specifies how traffic is shifted from one version of a Lambda function to another version during an Lambda deployment, or from one Amazon ECS task set to another during an Amazon ECS deployment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#time_based_canary ⇒ Types::TimeBasedCanary
A configuration that shifts traffic from one version of a Lambda function or ECS task set to another in two increments.
-
#time_based_linear ⇒ Types::TimeBasedLinear
A configuration that shifts traffic from one version of a Lambda function or Amazon ECS task set to another in equal increments, with an equal number of minutes between each increment.
-
#type ⇒ String
The type of traffic shifting (
TimeBasedCanaryorTimeBasedLinear) used by a deployment configuration.
Instance Attribute Details
#time_based_canary ⇒ Types::TimeBasedCanary
A configuration that shifts traffic from one version of a Lambda function or ECS task set to another in two increments. The original and target Lambda function versions or ECS task sets are specified in the deployment’s AppSpec file.
4787 4788 4789 4790 4791 4792 4793 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4787 class TrafficRoutingConfig < Struct.new( :type, :time_based_canary, :time_based_linear) SENSITIVE = [] include Aws::Structure end |
#time_based_linear ⇒ Types::TimeBasedLinear
A configuration that shifts traffic from one version of a Lambda function or Amazon ECS task set to another in equal increments, with an equal number of minutes between each increment. The original and target Lambda function versions or Amazon ECS task sets are specified in the deployment’s AppSpec file.
4787 4788 4789 4790 4791 4792 4793 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4787 class TrafficRoutingConfig < Struct.new( :type, :time_based_canary, :time_based_linear) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of traffic shifting (TimeBasedCanary or TimeBasedLinear) used by a deployment configuration.
4787 4788 4789 4790 4791 4792 4793 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4787 class TrafficRoutingConfig < Struct.new( :type, :time_based_canary, :time_based_linear) SENSITIVE = [] include Aws::Structure end |