Class: Aws::CodeDeploy::Types::UntagResourceInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codedeploy/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The Amazon Resource Name (ARN) that specifies from which resource to disassociate the tags with the keys in the TagKeys input parameter.

Returns:



4955
4956
4957
4958
4959
4960
# File 'lib/aws-sdk-codedeploy/types.rb', line 4955

class UntagResourceInput < Struct.new(
  :resource_arn,
  :tag_keys)
  SENSITIVE = []
  include Aws::Structure
end

#tag_keysArray<String>

A list of keys of Tag objects. The Tag objects identified by the keys are disassociated from the resource specified by the ResourceArn input parameter.

Returns:



4955
4956
4957
4958
4959
4960
# File 'lib/aws-sdk-codedeploy/types.rb', line 4955

class UntagResourceInput < Struct.new(
  :resource_arn,
  :tag_keys)
  SENSITIVE = []
  include Aws::Structure
end