Class: Aws::CodeDeploy::Types::UpdateDeploymentGroupInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::UpdateDeploymentGroupInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Represents the input of an UpdateDeploymentGroup operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alarm_configuration ⇒ Types::AlarmConfiguration
Information to add or change about Amazon CloudWatch alarms when the deployment group is updated.
-
#application_name ⇒ String
The application name that corresponds to the deployment group to update.
-
#auto_rollback_configuration ⇒ Types::AutoRollbackConfiguration
Information for an automatic rollback configuration that is added or changed when a deployment group is updated.
-
#auto_scaling_groups ⇒ Array<String>
The replacement list of Auto Scaling groups to be included in the deployment group, if you want to change them.
-
#blue_green_deployment_configuration ⇒ Types::BlueGreenDeploymentConfiguration
Information about blue/green deployment options for a deployment group.
-
#current_deployment_group_name ⇒ String
The current name of the deployment group.
-
#deployment_config_name ⇒ String
The replacement deployment configuration name to use, if you want to change it.
-
#deployment_style ⇒ Types::DeploymentStyle
Information about the type of deployment, either in-place or blue/green, you want to run and whether to route deployment traffic behind a load balancer.
-
#ec2_tag_filters ⇒ Array<Types::EC2TagFilter>
The replacement set of Amazon EC2 tags on which to filter, if you want to change them.
-
#ec2_tag_set ⇒ Types::EC2TagSet
Information about groups of tags applied to on-premises instances.
-
#ecs_services ⇒ Array<Types::ECSService>
The target Amazon ECS services in the deployment group.
-
#load_balancer_info ⇒ Types::LoadBalancerInfo
Information about the load balancer used in a deployment.
-
#new_deployment_group_name ⇒ String
The new name of the deployment group, if you want to change it.
-
#on_premises_instance_tag_filters ⇒ Array<Types::TagFilter>
The replacement set of on-premises instance tags on which to filter, if you want to change them.
-
#on_premises_tag_set ⇒ Types::OnPremisesTagSet
Information about an on-premises instance tag set.
-
#outdated_instances_strategy ⇒ String
Indicates what happens when new Amazon EC2 instances are launched mid-deployment and do not receive the deployed application revision.
-
#service_role_arn ⇒ String
A replacement ARN for the service role, if you want to change it.
-
#trigger_configurations ⇒ Array<Types::TriggerConfig>
Information about triggers to change when the deployment group is updated.
Instance Attribute Details
#alarm_configuration ⇒ Types::AlarmConfiguration
Information to add or change about Amazon CloudWatch alarms when the deployment group is updated.
5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5003 class UpdateDeploymentGroupInput < Struct.new( :application_name, :current_deployment_group_name, :new_deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set) SENSITIVE = [] include Aws::Structure end |
#application_name ⇒ String
The application name that corresponds to the deployment group to update.
5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5003 class UpdateDeploymentGroupInput < Struct.new( :application_name, :current_deployment_group_name, :new_deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set) SENSITIVE = [] include Aws::Structure end |
#auto_rollback_configuration ⇒ Types::AutoRollbackConfiguration
Information for an automatic rollback configuration that is added or changed when a deployment group is updated.
5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5003 class UpdateDeploymentGroupInput < Struct.new( :application_name, :current_deployment_group_name, :new_deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set) SENSITIVE = [] include Aws::Structure end |
#auto_scaling_groups ⇒ Array<String>
The replacement list of Auto Scaling groups to be included in the deployment group, if you want to change them.
-
To keep the Auto Scaling groups, enter their names or do not specify this parameter.
-
To remove Auto Scaling groups, specify a non-null empty list of Auto Scaling group names to detach all CodeDeploy-managed Auto Scaling lifecycle hooks. For examples, see [Amazon EC2 instances in an Amazon EC2 Auto Scaling group fail to launch and receive the error “Heartbeat Timeout”][1] in the *CodeDeploy User Guide*.
5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5003 class UpdateDeploymentGroupInput < Struct.new( :application_name, :current_deployment_group_name, :new_deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set) SENSITIVE = [] include Aws::Structure end |
#blue_green_deployment_configuration ⇒ Types::BlueGreenDeploymentConfiguration
Information about blue/green deployment options for a deployment group.
5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5003 class UpdateDeploymentGroupInput < Struct.new( :application_name, :current_deployment_group_name, :new_deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set) SENSITIVE = [] include Aws::Structure end |
#current_deployment_group_name ⇒ String
The current name of the deployment group.
5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5003 class UpdateDeploymentGroupInput < Struct.new( :application_name, :current_deployment_group_name, :new_deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set) SENSITIVE = [] include Aws::Structure end |
#deployment_config_name ⇒ String
The replacement deployment configuration name to use, if you want to change it.
5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5003 class UpdateDeploymentGroupInput < Struct.new( :application_name, :current_deployment_group_name, :new_deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set) SENSITIVE = [] include Aws::Structure end |
#deployment_style ⇒ Types::DeploymentStyle
Information about the type of deployment, either in-place or blue/green, you want to run and whether to route deployment traffic behind a load balancer.
5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5003 class UpdateDeploymentGroupInput < Struct.new( :application_name, :current_deployment_group_name, :new_deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set) SENSITIVE = [] include Aws::Structure end |
#ec2_tag_filters ⇒ Array<Types::EC2TagFilter>
The replacement set of Amazon EC2 tags on which to filter, if you want to change them. To keep the existing tags, enter their names. To remove tags, do not enter any tag names.
5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5003 class UpdateDeploymentGroupInput < Struct.new( :application_name, :current_deployment_group_name, :new_deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set) SENSITIVE = [] include Aws::Structure end |
#ec2_tag_set ⇒ Types::EC2TagSet
Information about groups of tags applied to on-premises instances. The deployment group includes only Amazon EC2 instances identified by all the tag groups.
5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5003 class UpdateDeploymentGroupInput < Struct.new( :application_name, :current_deployment_group_name, :new_deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set) SENSITIVE = [] include Aws::Structure end |
#ecs_services ⇒ Array<Types::ECSService>
The target Amazon ECS services in the deployment group. This applies only to deployment groups that use the Amazon ECS compute platform. A target Amazon ECS service is specified as an Amazon ECS cluster and service name pair using the format ‘<clustername>:<servicename>`.
5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5003 class UpdateDeploymentGroupInput < Struct.new( :application_name, :current_deployment_group_name, :new_deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set) SENSITIVE = [] include Aws::Structure end |
#load_balancer_info ⇒ Types::LoadBalancerInfo
Information about the load balancer used in a deployment.
5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5003 class UpdateDeploymentGroupInput < Struct.new( :application_name, :current_deployment_group_name, :new_deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set) SENSITIVE = [] include Aws::Structure end |
#new_deployment_group_name ⇒ String
The new name of the deployment group, if you want to change it.
5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5003 class UpdateDeploymentGroupInput < Struct.new( :application_name, :current_deployment_group_name, :new_deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set) SENSITIVE = [] include Aws::Structure end |
#on_premises_instance_tag_filters ⇒ Array<Types::TagFilter>
The replacement set of on-premises instance tags on which to filter, if you want to change them. To keep the existing tags, enter their names. To remove tags, do not enter any tag names.
5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5003 class UpdateDeploymentGroupInput < Struct.new( :application_name, :current_deployment_group_name, :new_deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set) SENSITIVE = [] include Aws::Structure end |
#on_premises_tag_set ⇒ Types::OnPremisesTagSet
Information about an on-premises instance tag set. The deployment group includes only on-premises instances identified by all the tag groups.
5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5003 class UpdateDeploymentGroupInput < Struct.new( :application_name, :current_deployment_group_name, :new_deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set) SENSITIVE = [] include Aws::Structure end |
#outdated_instances_strategy ⇒ String
Indicates what happens when new Amazon EC2 instances are launched mid-deployment and do not receive the deployed application revision.
If this option is set to UPDATE or is unspecified, CodeDeploy initiates one or more ‘auto-update outdated instances’ deployments to apply the deployed application revision to the new Amazon EC2 instances.
If this option is set to IGNORE, CodeDeploy does not initiate a deployment to update the new Amazon EC2 instances. This may result in instances having different revisions.
5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5003 class UpdateDeploymentGroupInput < Struct.new( :application_name, :current_deployment_group_name, :new_deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set) SENSITIVE = [] include Aws::Structure end |
#service_role_arn ⇒ String
A replacement ARN for the service role, if you want to change it.
5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5003 class UpdateDeploymentGroupInput < Struct.new( :application_name, :current_deployment_group_name, :new_deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set) SENSITIVE = [] include Aws::Structure end |
#trigger_configurations ⇒ Array<Types::TriggerConfig>
Information about triggers to change when the deployment group is updated. For examples, see [Edit a Trigger in a CodeDeploy Deployment Group][1] in the *CodeDeploy User Guide*.
[1]: docs.aws.amazon.com/codedeploy/latest/userguide/how-to-notify-edit.html
5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5003 class UpdateDeploymentGroupInput < Struct.new( :application_name, :current_deployment_group_name, :new_deployment_group_name, :deployment_config_name, :ec2_tag_filters, :on_premises_instance_tag_filters, :auto_scaling_groups, :service_role_arn, :trigger_configurations, :alarm_configuration, :auto_rollback_configuration, :outdated_instances_strategy, :deployment_style, :blue_green_deployment_configuration, :load_balancer_info, :ec2_tag_set, :ecs_services, :on_premises_tag_set) SENSITIVE = [] include Aws::Structure end |