Class: Aws::CodeDeploy::Types::BatchGetApplicationRevisionsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::BatchGetApplicationRevisionsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Note:
When making an API call, you may pass BatchGetApplicationRevisionsInput data as a hash:
{
application_name: "ApplicationName", # required
revisions: [ # required
{
revision_type: "S3", # accepts S3, GitHub, String, AppSpecContent
s3_location: {
bucket: "S3Bucket",
key: "S3Key",
bundle_type: "tar", # accepts tar, tgz, zip, YAML, JSON
version: "VersionId",
e_tag: "ETag",
},
git_hub_location: {
repository: "Repository",
commit_id: "CommitId",
},
string: {
content: "RawStringContent",
sha256: "RawStringSha256",
},
app_spec_content: {
content: "RawStringContent",
sha256: "RawStringSha256",
},
},
],
}
Represents the input of a BatchGetApplicationRevisions operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_name ⇒ String
The name of an AWS CodeDeploy application about which to get revision information.
-
#revisions ⇒ Array<Types::RevisionLocation>
An array of
RevisionLocationobjects that specify information to get about the application revisions, including type and location.
Instance Attribute Details
#application_name ⇒ String
The name of an AWS CodeDeploy application about which to get revision information.
335 336 337 338 339 340 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 335 class BatchGetApplicationRevisionsInput < Struct.new( :application_name, :revisions) SENSITIVE = [] include Aws::Structure end |
#revisions ⇒ Array<Types::RevisionLocation>
An array of RevisionLocation objects that specify information to get about the application revisions, including type and location. The maximum number of RevisionLocation objects you can specify is 25.
335 336 337 338 339 340 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 335 class BatchGetApplicationRevisionsInput < Struct.new( :application_name, :revisions) SENSITIVE = [] include Aws::Structure end |