Class: Aws::CodeDeploy::Types::CreateDeploymentConfigInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::CreateDeploymentConfigInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Represents the input of a CreateDeploymentConfig operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compute_platform ⇒ String
The destination platform type for the deployment (
Lambda,Server, orECS). -
#deployment_config_name ⇒ String
The name of the deployment configuration to create.
-
#minimum_healthy_hosts ⇒ Types::MinimumHealthyHosts
The minimum number of healthy instances that should be available at any time during the deployment.
-
#traffic_routing_config ⇒ Types::TrafficRoutingConfig
The configuration that specifies how the deployment traffic is routed.
Instance Attribute Details
#compute_platform ⇒ String
The destination platform type for the deployment (Lambda, Server, or ECS).
752 753 754 755 756 757 758 759 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 752 class CreateDeploymentConfigInput < Struct.new( :deployment_config_name, :minimum_healthy_hosts, :traffic_routing_config, :compute_platform) SENSITIVE = [] include Aws::Structure end |
#deployment_config_name ⇒ String
The name of the deployment configuration to create.
752 753 754 755 756 757 758 759 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 752 class CreateDeploymentConfigInput < Struct.new( :deployment_config_name, :minimum_healthy_hosts, :traffic_routing_config, :compute_platform) SENSITIVE = [] include Aws::Structure end |
#minimum_healthy_hosts ⇒ Types::MinimumHealthyHosts
The minimum number of healthy instances that should be available at any time during the deployment. There are two parameters expected in the input: type and value.
The type parameter takes either of the following values:
-
HOST_COUNT: The value parameter represents the minimum number of healthy instances as an absolute value.
-
FLEET_PERCENT: The value parameter represents the minimum number of healthy instances as a percentage of the total number of instances in the deployment. If you specify FLEET_PERCENT, at the start of the deployment, CodeDeploy converts the percentage to the equivalent number of instances and rounds up fractional instances.
The value parameter takes an integer.
For example, to set a minimum of 95% healthy instance, specify a type of FLEET_PERCENT and a value of 95.
752 753 754 755 756 757 758 759 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 752 class CreateDeploymentConfigInput < Struct.new( :deployment_config_name, :minimum_healthy_hosts, :traffic_routing_config, :compute_platform) SENSITIVE = [] include Aws::Structure end |
#traffic_routing_config ⇒ Types::TrafficRoutingConfig
The configuration that specifies how the deployment traffic is routed.
752 753 754 755 756 757 758 759 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 752 class CreateDeploymentConfigInput < Struct.new( :deployment_config_name, :minimum_healthy_hosts, :traffic_routing_config, :compute_platform) SENSITIVE = [] include Aws::Structure end |