Class: Aws::CodeDeploy::Types::DeleteDeploymentGroupOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::DeleteDeploymentGroupOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Represents the output of a DeleteDeploymentGroup operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hooks_not_cleaned_up ⇒ Array<Types::AutoScalingGroup>
If the output contains no data, and the corresponding deployment group contained at least one Auto Scaling group, CodeDeploy successfully removed all corresponding Auto Scaling lifecycle event hooks from the Amazon EC2 instances in the Auto Scaling group.
Instance Attribute Details
#hooks_not_cleaned_up ⇒ Array<Types::AutoScalingGroup>
If the output contains no data, and the corresponding deployment group contained at least one Auto Scaling group, CodeDeploy successfully removed all corresponding Auto Scaling lifecycle event hooks from the Amazon EC2 instances in the Auto Scaling group. If the output contains data, CodeDeploy could not remove some Auto Scaling lifecycle event hooks from the Amazon EC2 instances in the Auto Scaling group.
1151 1152 1153 1154 1155 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 1151 class DeleteDeploymentGroupOutput < Struct.new( :hooks_not_cleaned_up) SENSITIVE = [] include Aws::Structure end |