Class: Aws::CodeDeploy::Types::DeploymentInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::DeploymentInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Information about a deployment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_deployment_status_info ⇒ String
Provides information about the results of a deployment, such as whether instances in the original environment in a blue/green deployment were not terminated.
-
#application_name ⇒ String
The application name.
-
#auto_rollback_configuration ⇒ Types::AutoRollbackConfiguration
Information about the automatic rollback configuration associated with the deployment.
-
#blue_green_deployment_configuration ⇒ Types::BlueGreenDeploymentConfiguration
Information about blue/green deployment options for this deployment.
-
#complete_time ⇒ Time
A timestamp that indicates when the deployment was complete.
-
#compute_platform ⇒ String
The destination platform type for the deployment (
Lambda,Server, orECS). -
#create_time ⇒ Time
A timestamp that indicates when the deployment was created.
-
#creator ⇒ String
The means by which the deployment was created:.
-
#deployment_config_name ⇒ String
The deployment configuration name.
-
#deployment_group_name ⇒ String
The deployment group name.
-
#deployment_id ⇒ String
The unique ID of a deployment.
-
#deployment_overview ⇒ Types::DeploymentOverview
A summary of the deployment status of the instances in the deployment.
-
#deployment_status_messages ⇒ Array<String>
Messages that contain information about the status of a deployment.
-
#deployment_style ⇒ Types::DeploymentStyle
Information about the type of deployment, either in-place or blue/green, you want to run and whether to route deployment traffic behind a load balancer.
-
#description ⇒ String
A comment about the deployment.
-
#error_information ⇒ Types::ErrorInformation
Information about any error associated with this deployment.
-
#external_id ⇒ String
The unique ID for an external resource (for example, a CloudFormation stack ID) that is linked to this deployment.
-
#file_exists_behavior ⇒ String
Information about how AWS CodeDeploy handles files that already exist in a deployment target location but weren't part of the previous successful deployment.
-
#ignore_application_stop_failures ⇒ Boolean
If true, then if an
ApplicationStop,BeforeBlockTraffic, orAfterBlockTrafficdeployment lifecycle event to an instance fails, then the deployment continues to the next deployment lifecycle event. -
#instance_termination_wait_time_started ⇒ Boolean
Indicates whether the wait period set for the termination of instances in the original environment has started.
-
#load_balancer_info ⇒ Types::LoadBalancerInfo
Information about the load balancer used in the deployment.
-
#previous_revision ⇒ Types::RevisionLocation
Information about the application revision that was deployed to the deployment group before the most recent successful deployment.
-
#related_deployments ⇒ Types::RelatedDeployments
Information about deployments related to the specified deployment.
-
#revision ⇒ Types::RevisionLocation
Information about the location of stored application artifacts and the service from which to retrieve them.
-
#rollback_info ⇒ Types::RollbackInfo
Information about a deployment rollback.
-
#start_time ⇒ Time
A timestamp that indicates when the deployment was deployed to the deployment group.
-
#status ⇒ String
The current state of the deployment as a whole.
-
#target_instances ⇒ Types::TargetInstances
Information about the instances that belong to the replacement environment in a blue/green deployment.
-
#update_outdated_instances_only ⇒ Boolean
Indicates whether only instances that are not running the latest application revision are to be deployed to.
Instance Attribute Details
#additional_deployment_status_info ⇒ String
Provides information about the results of a deployment, such as whether instances in the original environment in a blue/green deployment were not terminated.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#application_name ⇒ String
The application name.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#auto_rollback_configuration ⇒ Types::AutoRollbackConfiguration
Information about the automatic rollback configuration associated with the deployment.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#blue_green_deployment_configuration ⇒ Types::BlueGreenDeploymentConfiguration
Information about blue/green deployment options for this deployment.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#complete_time ⇒ Time
A timestamp that indicates when the deployment was complete.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#compute_platform ⇒ String
The destination platform type for the deployment (Lambda,
Server, or ECS).
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
A timestamp that indicates when the deployment was created.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#creator ⇒ String
The means by which the deployment was created:
-
user: A user created the deployment. -
autoscaling: Amazon EC2 Auto Scaling created the deployment. -
codeDeployRollback: A rollback process created the deployment. -
CodeDeployAutoUpdate: An auto-update process created the deployment when it detected outdated EC2 instances.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#deployment_config_name ⇒ String
The deployment configuration name.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#deployment_group_name ⇒ String
The deployment group name.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#deployment_id ⇒ String
The unique ID of a deployment.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#deployment_overview ⇒ Types::DeploymentOverview
A summary of the deployment status of the instances in the deployment.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#deployment_status_messages ⇒ Array<String>
Messages that contain information about the status of a deployment.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#deployment_style ⇒ Types::DeploymentStyle
Information about the type of deployment, either in-place or blue/green, you want to run and whether to route deployment traffic behind a load balancer.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A comment about the deployment.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#error_information ⇒ Types::ErrorInformation
Information about any error associated with this deployment.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#external_id ⇒ String
The unique ID for an external resource (for example, a CloudFormation stack ID) that is linked to this deployment.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#file_exists_behavior ⇒ String
Information about how AWS CodeDeploy handles files that already exist in a deployment target location but weren't part of the previous successful deployment.
-
DISALLOW: The deployment fails. This is also the default behavior if no option is specified. -
OVERWRITE: The version of the file from the application revision currently being deployed replaces the version already on the instance. -
RETAIN: The version of the file already on the instance is kept and used as part of the new deployment.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#ignore_application_stop_failures ⇒ Boolean
If true, then if an ApplicationStop, BeforeBlockTraffic, or
AfterBlockTraffic deployment lifecycle event to an instance fails,
then the deployment continues to the next deployment lifecycle
event. For example, if ApplicationStop fails, the deployment
continues with DownloadBundle. If BeforeBlockTraffic fails, the
deployment continues with BlockTraffic. If AfterBlockTraffic
fails, the deployment continues with ApplicationStop.
If false or not specified, then if a lifecycle event fails during a deployment to an instance, that deployment fails. If deployment to that instance is part of an overall deployment and the number of healthy hosts is not less than the minimum number of healthy hosts, then a deployment to the next instance is attempted.
During a deployment, the AWS CodeDeploy agent runs the scripts
specified for ApplicationStop, BeforeBlockTraffic, and
AfterBlockTraffic in the AppSpec file from the previous successful
deployment. (All other scripts are run from the AppSpec file in the
current deployment.) If one of these scripts contains an error and
does not run successfully, the deployment can fail.
If the cause of the failure is a script from the last successful
deployment that will never run successfully, create a new deployment
and use ignoreApplicationStopFailures to specify that the
ApplicationStop, BeforeBlockTraffic, and AfterBlockTraffic
failures should be ignored.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#instance_termination_wait_time_started ⇒ Boolean
Indicates whether the wait period set for the termination of instances in the original environment has started. Status is 'false' if the KEEP_ALIVE option is specified. Otherwise, 'true' as soon as the termination wait period starts.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#load_balancer_info ⇒ Types::LoadBalancerInfo
Information about the load balancer used in the deployment.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#previous_revision ⇒ Types::RevisionLocation
Information about the application revision that was deployed to the deployment group before the most recent successful deployment.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#related_deployments ⇒ Types::RelatedDeployments
Information about deployments related to the specified deployment.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#revision ⇒ Types::RevisionLocation
Information about the location of stored application artifacts and the service from which to retrieve them.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#rollback_info ⇒ Types::RollbackInfo
Information about a deployment rollback.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
A timestamp that indicates when the deployment was deployed to the deployment group.
In some cases, the reported value of the start time might be later than the complete time. This is due to differences in the clock settings of backend servers that participate in the deployment process.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current state of the deployment as a whole.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#target_instances ⇒ Types::TargetInstances
Information about the instances that belong to the replacement environment in a blue/green deployment.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |
#update_outdated_instances_only ⇒ Boolean
Indicates whether only instances that are not running the latest application revision are to be deployed to.
2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 2060 class DeploymentInfo < Struct.new( :application_name, :deployment_group_name, :deployment_config_name, :deployment_id, :previous_revision, :revision, :status, :error_information, :create_time, :start_time, :complete_time, :deployment_overview, :description, :creator, :ignore_application_stop_failures, :auto_rollback_configuration, :update_outdated_instances_only, :rollback_info, :deployment_style, :target_instances, :instance_termination_wait_time_started, :blue_green_deployment_configuration, :load_balancer_info, :additional_deployment_status_info, :file_exists_behavior, :deployment_status_messages, :compute_platform, :external_id, :related_deployments) SENSITIVE = [] include Aws::Structure end |