Class: Aws::CodeDeploy::Types::ListDeploymentGroupsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::ListDeploymentGroupsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Note:
When making an API call, you may pass ListDeploymentGroupsInput data as a hash:
{
application_name: "ApplicationName", # required
next_token: "NextToken",
}
Represents the input of a ListDeploymentGroups operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_name ⇒ String
The name of an AWS CodeDeploy application associated with the IAM user or AWS account.
-
#next_token ⇒ String
An identifier returned from the previous list deployment groups call.
Instance Attribute Details
#application_name ⇒ String
The name of an AWS CodeDeploy application associated with the IAM user or AWS account.
4149 4150 4151 4152 4153 4154 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4149 class ListDeploymentGroupsInput < Struct.new( :application_name, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An identifier returned from the previous list deployment groups call. It can be used to return the next set of deployment groups in the list.
4149 4150 4151 4152 4153 4154 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4149 class ListDeploymentGroupsInput < Struct.new( :application_name, :next_token) SENSITIVE = [] include Aws::Structure end |