Class: Aws::CodeDeploy::Types::ListTagsForResourceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::ListTagsForResourceInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Note:
When making an API call, you may pass ListTagsForResourceInput data as a hash:
{
resource_arn: "Arn", # required
next_token: "NextToken",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
An identifier returned from the previous
ListTagsForResourcecall. -
#resource_arn ⇒ String
The ARN of a CodeDeploy resource.
Instance Attribute Details
#next_token ⇒ String
An identifier returned from the previous ListTagsForResource call. It can be used to return the next set of applications in the list.
4563 4564 4565 4566 4567 4568 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4563 class ListTagsForResourceInput < Struct.new( :resource_arn, :next_token) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The ARN of a CodeDeploy resource. ListTagsForResource returns all the tags associated with the resource that is identified by the ResourceArn.
4563 4564 4565 4566 4567 4568 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4563 class ListTagsForResourceInput < Struct.new( :resource_arn, :next_token) SENSITIVE = [] include Aws::Structure end |