Class: Aws::CodeDeploy::Types::StopDeploymentInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::StopDeploymentInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Note:
When making an API call, you may pass StopDeploymentInput data as a hash:
{
deployment_id: "DeploymentId", # required
auto_rollback_enabled: false,
}
Represents the input of a StopDeployment operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_rollback_enabled ⇒ Boolean
Indicates, when a deployment is stopped, whether instances that have been updated should be rolled back to the previous version of the application revision.
-
#deployment_id ⇒ String
The unique ID of a deployment.
Instance Attribute Details
#auto_rollback_enabled ⇒ Boolean
Indicates, when a deployment is stopped, whether instances that have been updated should be rolled back to the previous version of the application revision.
5195 5196 5197 5198 5199 5200 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5195 class StopDeploymentInput < Struct.new( :deployment_id, :auto_rollback_enabled) SENSITIVE = [] include Aws::Structure end |
#deployment_id ⇒ String
The unique ID of a deployment.
5195 5196 5197 5198 5199 5200 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5195 class StopDeploymentInput < Struct.new( :deployment_id, :auto_rollback_enabled) SENSITIVE = [] include Aws::Structure end |