Class: Aws::CodeDeploy::Types::TimeBasedLinear
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::TimeBasedLinear
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
A configuration that shifts traffic from one version of a Lambda function or ECS task set to another in equal increments, with an equal number of minutes between each increment. The original and target Lambda function versions or ECS task sets are specified in the deployment’s AppSpec file.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#linear_interval ⇒ Integer
The number of minutes between each incremental traffic shift of a
TimeBasedLineardeployment. -
#linear_percentage ⇒ Integer
The percentage of traffic that is shifted at the start of each increment of a
TimeBasedLineardeployment.
Instance Attribute Details
#linear_interval ⇒ Integer
The number of minutes between each incremental traffic shift of a TimeBasedLinear deployment.
4708 4709 4710 4711 4712 4713 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4708 class TimeBasedLinear < Struct.new( :linear_percentage, :linear_interval) SENSITIVE = [] include Aws::Structure end |
#linear_percentage ⇒ Integer
The percentage of traffic that is shifted at the start of each increment of a TimeBasedLinear deployment.
4708 4709 4710 4711 4712 4713 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 4708 class TimeBasedLinear < Struct.new( :linear_percentage, :linear_interval) SENSITIVE = [] include Aws::Structure end |