Class: Aws::CodeDeploy::Types::TimeBasedLinear

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codedeploy/types.rb

Overview

A configuration that shifts traffic from one version of a Lambda function or ECS task set to another in equal increments, with an equal number of minutes between each increment. The original and target Lambda function versions or ECS task sets are specified in the deployment’s AppSpec file.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#linear_intervalInteger

The number of minutes between each incremental traffic shift of a TimeBasedLinear deployment.

Returns:

  • (Integer)


4687
4688
4689
4690
4691
4692
# File 'lib/aws-sdk-codedeploy/types.rb', line 4687

class TimeBasedLinear < Struct.new(
  :linear_percentage,
  :linear_interval)
  SENSITIVE = []
  include Aws::Structure
end

#linear_percentageInteger

The percentage of traffic that is shifted at the start of each increment of a TimeBasedLinear deployment.

Returns:

  • (Integer)


4687
4688
4689
4690
4691
4692
# File 'lib/aws-sdk-codedeploy/types.rb', line 4687

class TimeBasedLinear < Struct.new(
  :linear_percentage,
  :linear_interval)
  SENSITIVE = []
  include Aws::Structure
end