Class: Aws::CodeDeploy::Types::UpdateDeploymentGroupOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codedeploy/types.rb

Overview

Represents the output of an UpdateDeploymentGroup operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#hooks_not_cleaned_upArray<Types::AutoScalingGroup>

If the output contains no data, and the corresponding deployment group contained at least one Auto Scaling group, CodeDeploy successfully removed all corresponding Auto Scaling lifecycle event hooks from the Amazon Web Services account. If the output contains data, CodeDeploy could not remove some Auto Scaling lifecycle event hooks from the Amazon Web Services account.

Returns:



5039
5040
5041
5042
5043
# File 'lib/aws-sdk-codedeploy/types.rb', line 5039

class UpdateDeploymentGroupOutput < Struct.new(
  :hooks_not_cleaned_up)
  SENSITIVE = []
  include Aws::Structure
end