Class: Aws::CodeDeploy::Types::UpdateDeploymentGroupOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeDeploy::Types::UpdateDeploymentGroupOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codedeploy/types.rb
Overview
Represents the output of an UpdateDeploymentGroup operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hooks_not_cleaned_up ⇒ Array<Types::AutoScalingGroup>
If the output contains no data, and the corresponding deployment group contained at least one Auto Scaling group, CodeDeploy successfully removed all corresponding Auto Scaling lifecycle event hooks from the Amazon Web Services account.
Instance Attribute Details
#hooks_not_cleaned_up ⇒ Array<Types::AutoScalingGroup>
If the output contains no data, and the corresponding deployment group contained at least one Auto Scaling group, CodeDeploy successfully removed all corresponding Auto Scaling lifecycle event hooks from the Amazon Web Services account. If the output contains data, CodeDeploy could not remove some Auto Scaling lifecycle event hooks from the Amazon Web Services account.
5018 5019 5020 5021 5022 |
# File 'lib/aws-sdk-codedeploy/types.rb', line 5018 class UpdateDeploymentGroupOutput < Struct.new( :hooks_not_cleaned_up) SENSITIVE = [] include Aws::Structure end |